session

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the session type in the database.
	Label = "session"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldAgentSessionID holds the string denoting the agent_session_id field in the database.
	FieldAgentSessionID = "agent_session_id"
	// FieldAgentName holds the string denoting the agent_name field in the database.
	FieldAgentName = "agent_name"
	// FieldAgentVersion holds the string denoting the agent_version field in the database.
	FieldAgentVersion = "agent_version"
	// FieldStartedAt holds the string denoting the started_at field in the database.
	FieldStartedAt = "started_at"
	// FieldEndedAt holds the string denoting the ended_at field in the database.
	FieldEndedAt = "ended_at"
	// FieldWorkingDirectory holds the string denoting the working_directory field in the database.
	FieldWorkingDirectory = "working_directory"
	// FieldProjectName holds the string denoting the project_name field in the database.
	FieldProjectName = "project_name"
	// FieldTotalActions holds the string denoting the total_actions field in the database.
	FieldTotalActions = "total_actions"
	// FieldFilesRead holds the string denoting the files_read field in the database.
	FieldFilesRead = "files_read"
	// FieldFilesWritten holds the string denoting the files_written field in the database.
	FieldFilesWritten = "files_written"
	// FieldCommandsExecuted holds the string denoting the commands_executed field in the database.
	FieldCommandsExecuted = "commands_executed"
	// FieldErrors holds the string denoting the errors field in the database.
	FieldErrors = "errors"
	// FieldSensitiveActions holds the string denoting the sensitive_actions field in the database.
	FieldSensitiveActions = "sensitive_actions"
	// FieldBlockedActions holds the string denoting the blocked_actions field in the database.
	FieldBlockedActions = "blocked_actions"
	// FieldTranscriptPath holds the string denoting the transcript_path field in the database.
	FieldTranscriptPath = "transcript_path"
	// FieldInputTokens holds the string denoting the input_tokens field in the database.
	FieldInputTokens = "input_tokens"
	// FieldOutputTokens holds the string denoting the output_tokens field in the database.
	FieldOutputTokens = "output_tokens"
	// FieldCacheReadTokens holds the string denoting the cache_read_tokens field in the database.
	FieldCacheReadTokens = "cache_read_tokens"
	// FieldCacheWriteTokens holds the string denoting the cache_write_tokens field in the database.
	FieldCacheWriteTokens = "cache_write_tokens"
	// FieldEstimatedCostUsd holds the string denoting the estimated_cost_usd field in the database.
	FieldEstimatedCostUsd = "estimated_cost_usd"
	// FieldModelUsage holds the string denoting the model_usage field in the database.
	FieldModelUsage = "model_usage"
	// FieldCostSource holds the string denoting the cost_source field in the database.
	FieldCostSource = "cost_source"
	// FieldCostComputedAt holds the string denoting the cost_computed_at field in the database.
	FieldCostComputedAt = "cost_computed_at"
	// EdgeEvents holds the string denoting the events edge name in mutations.
	EdgeEvents = "events"
	// Table holds the table name of the session in the database.
	Table = "sessions"
	// EventsTable is the table that holds the events relation/edge.
	EventsTable = "audit_events"
	// EventsInverseTable is the table name for the AuditEvent entity.
	// It exists in this package in order to avoid circular dependency with the "auditevent" package.
	EventsInverseTable = "audit_events"
	// EventsColumn is the table column denoting the events relation/edge.
	EventsColumn = "session_id"
)

Variables

var (
	// AgentNameValidator is a validator for the "agent_name" field. It is called by the builders before save.
	AgentNameValidator func(string) error
	// DefaultStartedAt holds the default value on creation for the "started_at" field.
	DefaultStartedAt func() time.Time
	// DefaultTotalActions holds the default value on creation for the "total_actions" field.
	DefaultTotalActions int
	// DefaultFilesRead holds the default value on creation for the "files_read" field.
	DefaultFilesRead int
	// DefaultFilesWritten holds the default value on creation for the "files_written" field.
	DefaultFilesWritten int
	// DefaultCommandsExecuted holds the default value on creation for the "commands_executed" field.
	DefaultCommandsExecuted int
	// DefaultErrors holds the default value on creation for the "errors" field.
	DefaultErrors int
	// DefaultSensitiveActions holds the default value on creation for the "sensitive_actions" field.
	DefaultSensitiveActions int
	// DefaultBlockedActions holds the default value on creation for the "blocked_actions" field.
	DefaultBlockedActions int
	// DefaultInputTokens holds the default value on creation for the "input_tokens" field.
	DefaultInputTokens int64
	// DefaultOutputTokens holds the default value on creation for the "output_tokens" field.
	DefaultOutputTokens int64
	// DefaultCacheReadTokens holds the default value on creation for the "cache_read_tokens" field.
	DefaultCacheReadTokens int64
	// DefaultCacheWriteTokens holds the default value on creation for the "cache_write_tokens" field.
	DefaultCacheWriteTokens int64
	// DefaultEstimatedCostUsd holds the default value on creation for the "estimated_cost_usd" field.
	DefaultEstimatedCostUsd float64
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for session fields.

Functions

func AgentName

func AgentName(v string) predicate.Session

AgentName applies equality check predicate on the "agent_name" field. It's identical to AgentNameEQ.

func AgentNameContains

func AgentNameContains(v string) predicate.Session

AgentNameContains applies the Contains predicate on the "agent_name" field.

func AgentNameContainsFold

func AgentNameContainsFold(v string) predicate.Session

AgentNameContainsFold applies the ContainsFold predicate on the "agent_name" field.

func AgentNameEQ

func AgentNameEQ(v string) predicate.Session

AgentNameEQ applies the EQ predicate on the "agent_name" field.

func AgentNameEqualFold

func AgentNameEqualFold(v string) predicate.Session

AgentNameEqualFold applies the EqualFold predicate on the "agent_name" field.

func AgentNameGT

func AgentNameGT(v string) predicate.Session

AgentNameGT applies the GT predicate on the "agent_name" field.

func AgentNameGTE

func AgentNameGTE(v string) predicate.Session

AgentNameGTE applies the GTE predicate on the "agent_name" field.

func AgentNameHasPrefix

func AgentNameHasPrefix(v string) predicate.Session

AgentNameHasPrefix applies the HasPrefix predicate on the "agent_name" field.

func AgentNameHasSuffix

func AgentNameHasSuffix(v string) predicate.Session

AgentNameHasSuffix applies the HasSuffix predicate on the "agent_name" field.

func AgentNameIn

func AgentNameIn(vs ...string) predicate.Session

AgentNameIn applies the In predicate on the "agent_name" field.

func AgentNameLT

func AgentNameLT(v string) predicate.Session

AgentNameLT applies the LT predicate on the "agent_name" field.

func AgentNameLTE

func AgentNameLTE(v string) predicate.Session

AgentNameLTE applies the LTE predicate on the "agent_name" field.

func AgentNameNEQ

func AgentNameNEQ(v string) predicate.Session

AgentNameNEQ applies the NEQ predicate on the "agent_name" field.

func AgentNameNotIn

func AgentNameNotIn(vs ...string) predicate.Session

AgentNameNotIn applies the NotIn predicate on the "agent_name" field.

func AgentSessionID

func AgentSessionID(v string) predicate.Session

AgentSessionID applies equality check predicate on the "agent_session_id" field. It's identical to AgentSessionIDEQ.

func AgentSessionIDContains

func AgentSessionIDContains(v string) predicate.Session

AgentSessionIDContains applies the Contains predicate on the "agent_session_id" field.

func AgentSessionIDContainsFold

func AgentSessionIDContainsFold(v string) predicate.Session

AgentSessionIDContainsFold applies the ContainsFold predicate on the "agent_session_id" field.

func AgentSessionIDEQ

func AgentSessionIDEQ(v string) predicate.Session

AgentSessionIDEQ applies the EQ predicate on the "agent_session_id" field.

func AgentSessionIDEqualFold

func AgentSessionIDEqualFold(v string) predicate.Session

AgentSessionIDEqualFold applies the EqualFold predicate on the "agent_session_id" field.

func AgentSessionIDGT

func AgentSessionIDGT(v string) predicate.Session

AgentSessionIDGT applies the GT predicate on the "agent_session_id" field.

func AgentSessionIDGTE

func AgentSessionIDGTE(v string) predicate.Session

AgentSessionIDGTE applies the GTE predicate on the "agent_session_id" field.

func AgentSessionIDHasPrefix

func AgentSessionIDHasPrefix(v string) predicate.Session

AgentSessionIDHasPrefix applies the HasPrefix predicate on the "agent_session_id" field.

func AgentSessionIDHasSuffix

func AgentSessionIDHasSuffix(v string) predicate.Session

AgentSessionIDHasSuffix applies the HasSuffix predicate on the "agent_session_id" field.

func AgentSessionIDIn

func AgentSessionIDIn(vs ...string) predicate.Session

AgentSessionIDIn applies the In predicate on the "agent_session_id" field.

func AgentSessionIDIsNil

func AgentSessionIDIsNil() predicate.Session

AgentSessionIDIsNil applies the IsNil predicate on the "agent_session_id" field.

func AgentSessionIDLT

func AgentSessionIDLT(v string) predicate.Session

AgentSessionIDLT applies the LT predicate on the "agent_session_id" field.

func AgentSessionIDLTE

func AgentSessionIDLTE(v string) predicate.Session

AgentSessionIDLTE applies the LTE predicate on the "agent_session_id" field.

func AgentSessionIDNEQ

func AgentSessionIDNEQ(v string) predicate.Session

AgentSessionIDNEQ applies the NEQ predicate on the "agent_session_id" field.

func AgentSessionIDNotIn

func AgentSessionIDNotIn(vs ...string) predicate.Session

AgentSessionIDNotIn applies the NotIn predicate on the "agent_session_id" field.

func AgentSessionIDNotNil

func AgentSessionIDNotNil() predicate.Session

AgentSessionIDNotNil applies the NotNil predicate on the "agent_session_id" field.

func AgentVersion

func AgentVersion(v string) predicate.Session

AgentVersion applies equality check predicate on the "agent_version" field. It's identical to AgentVersionEQ.

func AgentVersionContains

func AgentVersionContains(v string) predicate.Session

AgentVersionContains applies the Contains predicate on the "agent_version" field.

func AgentVersionContainsFold

func AgentVersionContainsFold(v string) predicate.Session

AgentVersionContainsFold applies the ContainsFold predicate on the "agent_version" field.

func AgentVersionEQ

func AgentVersionEQ(v string) predicate.Session

AgentVersionEQ applies the EQ predicate on the "agent_version" field.

func AgentVersionEqualFold

func AgentVersionEqualFold(v string) predicate.Session

AgentVersionEqualFold applies the EqualFold predicate on the "agent_version" field.

func AgentVersionGT

func AgentVersionGT(v string) predicate.Session

AgentVersionGT applies the GT predicate on the "agent_version" field.

func AgentVersionGTE

func AgentVersionGTE(v string) predicate.Session

AgentVersionGTE applies the GTE predicate on the "agent_version" field.

func AgentVersionHasPrefix

func AgentVersionHasPrefix(v string) predicate.Session

AgentVersionHasPrefix applies the HasPrefix predicate on the "agent_version" field.

func AgentVersionHasSuffix

func AgentVersionHasSuffix(v string) predicate.Session

AgentVersionHasSuffix applies the HasSuffix predicate on the "agent_version" field.

func AgentVersionIn

func AgentVersionIn(vs ...string) predicate.Session

AgentVersionIn applies the In predicate on the "agent_version" field.

func AgentVersionIsNil

func AgentVersionIsNil() predicate.Session

AgentVersionIsNil applies the IsNil predicate on the "agent_version" field.

func AgentVersionLT

func AgentVersionLT(v string) predicate.Session

AgentVersionLT applies the LT predicate on the "agent_version" field.

func AgentVersionLTE

func AgentVersionLTE(v string) predicate.Session

AgentVersionLTE applies the LTE predicate on the "agent_version" field.

func AgentVersionNEQ

func AgentVersionNEQ(v string) predicate.Session

AgentVersionNEQ applies the NEQ predicate on the "agent_version" field.

func AgentVersionNotIn

func AgentVersionNotIn(vs ...string) predicate.Session

AgentVersionNotIn applies the NotIn predicate on the "agent_version" field.

func AgentVersionNotNil

func AgentVersionNotNil() predicate.Session

AgentVersionNotNil applies the NotNil predicate on the "agent_version" field.

func And

func And(predicates ...predicate.Session) predicate.Session

And groups predicates with the AND operator between them.

func BlockedActions added in v0.5.0

func BlockedActions(v int) predicate.Session

BlockedActions applies equality check predicate on the "blocked_actions" field. It's identical to BlockedActionsEQ.

func BlockedActionsEQ added in v0.5.0

func BlockedActionsEQ(v int) predicate.Session

BlockedActionsEQ applies the EQ predicate on the "blocked_actions" field.

func BlockedActionsGT added in v0.5.0

func BlockedActionsGT(v int) predicate.Session

BlockedActionsGT applies the GT predicate on the "blocked_actions" field.

func BlockedActionsGTE added in v0.5.0

func BlockedActionsGTE(v int) predicate.Session

BlockedActionsGTE applies the GTE predicate on the "blocked_actions" field.

func BlockedActionsIn added in v0.5.0

func BlockedActionsIn(vs ...int) predicate.Session

BlockedActionsIn applies the In predicate on the "blocked_actions" field.

func BlockedActionsLT added in v0.5.0

func BlockedActionsLT(v int) predicate.Session

BlockedActionsLT applies the LT predicate on the "blocked_actions" field.

func BlockedActionsLTE added in v0.5.0

func BlockedActionsLTE(v int) predicate.Session

BlockedActionsLTE applies the LTE predicate on the "blocked_actions" field.

func BlockedActionsNEQ added in v0.5.0

func BlockedActionsNEQ(v int) predicate.Session

BlockedActionsNEQ applies the NEQ predicate on the "blocked_actions" field.

func BlockedActionsNotIn added in v0.5.0

func BlockedActionsNotIn(vs ...int) predicate.Session

BlockedActionsNotIn applies the NotIn predicate on the "blocked_actions" field.

func CacheReadTokens added in v0.4.0

func CacheReadTokens(v int64) predicate.Session

CacheReadTokens applies equality check predicate on the "cache_read_tokens" field. It's identical to CacheReadTokensEQ.

func CacheReadTokensEQ added in v0.4.0

func CacheReadTokensEQ(v int64) predicate.Session

CacheReadTokensEQ applies the EQ predicate on the "cache_read_tokens" field.

func CacheReadTokensGT added in v0.4.0

func CacheReadTokensGT(v int64) predicate.Session

CacheReadTokensGT applies the GT predicate on the "cache_read_tokens" field.

func CacheReadTokensGTE added in v0.4.0

func CacheReadTokensGTE(v int64) predicate.Session

CacheReadTokensGTE applies the GTE predicate on the "cache_read_tokens" field.

func CacheReadTokensIn added in v0.4.0

func CacheReadTokensIn(vs ...int64) predicate.Session

CacheReadTokensIn applies the In predicate on the "cache_read_tokens" field.

func CacheReadTokensLT added in v0.4.0

func CacheReadTokensLT(v int64) predicate.Session

CacheReadTokensLT applies the LT predicate on the "cache_read_tokens" field.

func CacheReadTokensLTE added in v0.4.0

func CacheReadTokensLTE(v int64) predicate.Session

CacheReadTokensLTE applies the LTE predicate on the "cache_read_tokens" field.

func CacheReadTokensNEQ added in v0.4.0

func CacheReadTokensNEQ(v int64) predicate.Session

CacheReadTokensNEQ applies the NEQ predicate on the "cache_read_tokens" field.

func CacheReadTokensNotIn added in v0.4.0

func CacheReadTokensNotIn(vs ...int64) predicate.Session

CacheReadTokensNotIn applies the NotIn predicate on the "cache_read_tokens" field.

func CacheWriteTokens added in v0.4.0

func CacheWriteTokens(v int64) predicate.Session

CacheWriteTokens applies equality check predicate on the "cache_write_tokens" field. It's identical to CacheWriteTokensEQ.

func CacheWriteTokensEQ added in v0.4.0

func CacheWriteTokensEQ(v int64) predicate.Session

CacheWriteTokensEQ applies the EQ predicate on the "cache_write_tokens" field.

func CacheWriteTokensGT added in v0.4.0

func CacheWriteTokensGT(v int64) predicate.Session

CacheWriteTokensGT applies the GT predicate on the "cache_write_tokens" field.

func CacheWriteTokensGTE added in v0.4.0

func CacheWriteTokensGTE(v int64) predicate.Session

CacheWriteTokensGTE applies the GTE predicate on the "cache_write_tokens" field.

func CacheWriteTokensIn added in v0.4.0

func CacheWriteTokensIn(vs ...int64) predicate.Session

CacheWriteTokensIn applies the In predicate on the "cache_write_tokens" field.

func CacheWriteTokensLT added in v0.4.0

func CacheWriteTokensLT(v int64) predicate.Session

CacheWriteTokensLT applies the LT predicate on the "cache_write_tokens" field.

func CacheWriteTokensLTE added in v0.4.0

func CacheWriteTokensLTE(v int64) predicate.Session

CacheWriteTokensLTE applies the LTE predicate on the "cache_write_tokens" field.

func CacheWriteTokensNEQ added in v0.4.0

func CacheWriteTokensNEQ(v int64) predicate.Session

CacheWriteTokensNEQ applies the NEQ predicate on the "cache_write_tokens" field.

func CacheWriteTokensNotIn added in v0.4.0

func CacheWriteTokensNotIn(vs ...int64) predicate.Session

CacheWriteTokensNotIn applies the NotIn predicate on the "cache_write_tokens" field.

func CommandsExecuted

func CommandsExecuted(v int) predicate.Session

CommandsExecuted applies equality check predicate on the "commands_executed" field. It's identical to CommandsExecutedEQ.

func CommandsExecutedEQ

func CommandsExecutedEQ(v int) predicate.Session

CommandsExecutedEQ applies the EQ predicate on the "commands_executed" field.

func CommandsExecutedGT

func CommandsExecutedGT(v int) predicate.Session

CommandsExecutedGT applies the GT predicate on the "commands_executed" field.

func CommandsExecutedGTE

func CommandsExecutedGTE(v int) predicate.Session

CommandsExecutedGTE applies the GTE predicate on the "commands_executed" field.

func CommandsExecutedIn

func CommandsExecutedIn(vs ...int) predicate.Session

CommandsExecutedIn applies the In predicate on the "commands_executed" field.

func CommandsExecutedLT

func CommandsExecutedLT(v int) predicate.Session

CommandsExecutedLT applies the LT predicate on the "commands_executed" field.

func CommandsExecutedLTE

func CommandsExecutedLTE(v int) predicate.Session

CommandsExecutedLTE applies the LTE predicate on the "commands_executed" field.

func CommandsExecutedNEQ

func CommandsExecutedNEQ(v int) predicate.Session

CommandsExecutedNEQ applies the NEQ predicate on the "commands_executed" field.

func CommandsExecutedNotIn

func CommandsExecutedNotIn(vs ...int) predicate.Session

CommandsExecutedNotIn applies the NotIn predicate on the "commands_executed" field.

func CostComputedAt added in v0.4.0

func CostComputedAt(v time.Time) predicate.Session

CostComputedAt applies equality check predicate on the "cost_computed_at" field. It's identical to CostComputedAtEQ.

func CostComputedAtEQ added in v0.4.0

func CostComputedAtEQ(v time.Time) predicate.Session

CostComputedAtEQ applies the EQ predicate on the "cost_computed_at" field.

func CostComputedAtGT added in v0.4.0

func CostComputedAtGT(v time.Time) predicate.Session

CostComputedAtGT applies the GT predicate on the "cost_computed_at" field.

func CostComputedAtGTE added in v0.4.0

func CostComputedAtGTE(v time.Time) predicate.Session

CostComputedAtGTE applies the GTE predicate on the "cost_computed_at" field.

func CostComputedAtIn added in v0.4.0

func CostComputedAtIn(vs ...time.Time) predicate.Session

CostComputedAtIn applies the In predicate on the "cost_computed_at" field.

func CostComputedAtIsNil added in v0.4.0

func CostComputedAtIsNil() predicate.Session

CostComputedAtIsNil applies the IsNil predicate on the "cost_computed_at" field.

func CostComputedAtLT added in v0.4.0

func CostComputedAtLT(v time.Time) predicate.Session

CostComputedAtLT applies the LT predicate on the "cost_computed_at" field.

func CostComputedAtLTE added in v0.4.0

func CostComputedAtLTE(v time.Time) predicate.Session

CostComputedAtLTE applies the LTE predicate on the "cost_computed_at" field.

func CostComputedAtNEQ added in v0.4.0

func CostComputedAtNEQ(v time.Time) predicate.Session

CostComputedAtNEQ applies the NEQ predicate on the "cost_computed_at" field.

func CostComputedAtNotIn added in v0.4.0

func CostComputedAtNotIn(vs ...time.Time) predicate.Session

CostComputedAtNotIn applies the NotIn predicate on the "cost_computed_at" field.

func CostComputedAtNotNil added in v0.4.0

func CostComputedAtNotNil() predicate.Session

CostComputedAtNotNil applies the NotNil predicate on the "cost_computed_at" field.

func CostSource added in v0.4.0

func CostSource(v string) predicate.Session

CostSource applies equality check predicate on the "cost_source" field. It's identical to CostSourceEQ.

func CostSourceContains added in v0.4.0

func CostSourceContains(v string) predicate.Session

CostSourceContains applies the Contains predicate on the "cost_source" field.

func CostSourceContainsFold added in v0.4.0

func CostSourceContainsFold(v string) predicate.Session

CostSourceContainsFold applies the ContainsFold predicate on the "cost_source" field.

func CostSourceEQ added in v0.4.0

func CostSourceEQ(v string) predicate.Session

CostSourceEQ applies the EQ predicate on the "cost_source" field.

func CostSourceEqualFold added in v0.4.0

func CostSourceEqualFold(v string) predicate.Session

CostSourceEqualFold applies the EqualFold predicate on the "cost_source" field.

func CostSourceGT added in v0.4.0

func CostSourceGT(v string) predicate.Session

CostSourceGT applies the GT predicate on the "cost_source" field.

func CostSourceGTE added in v0.4.0

func CostSourceGTE(v string) predicate.Session

CostSourceGTE applies the GTE predicate on the "cost_source" field.

func CostSourceHasPrefix added in v0.4.0

func CostSourceHasPrefix(v string) predicate.Session

CostSourceHasPrefix applies the HasPrefix predicate on the "cost_source" field.

func CostSourceHasSuffix added in v0.4.0

func CostSourceHasSuffix(v string) predicate.Session

CostSourceHasSuffix applies the HasSuffix predicate on the "cost_source" field.

func CostSourceIn added in v0.4.0

func CostSourceIn(vs ...string) predicate.Session

CostSourceIn applies the In predicate on the "cost_source" field.

func CostSourceIsNil added in v0.4.0

func CostSourceIsNil() predicate.Session

CostSourceIsNil applies the IsNil predicate on the "cost_source" field.

func CostSourceLT added in v0.4.0

func CostSourceLT(v string) predicate.Session

CostSourceLT applies the LT predicate on the "cost_source" field.

func CostSourceLTE added in v0.4.0

func CostSourceLTE(v string) predicate.Session

CostSourceLTE applies the LTE predicate on the "cost_source" field.

func CostSourceNEQ added in v0.4.0

func CostSourceNEQ(v string) predicate.Session

CostSourceNEQ applies the NEQ predicate on the "cost_source" field.

func CostSourceNotIn added in v0.4.0

func CostSourceNotIn(vs ...string) predicate.Session

CostSourceNotIn applies the NotIn predicate on the "cost_source" field.

func CostSourceNotNil added in v0.4.0

func CostSourceNotNil() predicate.Session

CostSourceNotNil applies the NotNil predicate on the "cost_source" field.

func EndedAt

func EndedAt(v time.Time) predicate.Session

EndedAt applies equality check predicate on the "ended_at" field. It's identical to EndedAtEQ.

func EndedAtEQ

func EndedAtEQ(v time.Time) predicate.Session

EndedAtEQ applies the EQ predicate on the "ended_at" field.

func EndedAtGT

func EndedAtGT(v time.Time) predicate.Session

EndedAtGT applies the GT predicate on the "ended_at" field.

func EndedAtGTE

func EndedAtGTE(v time.Time) predicate.Session

EndedAtGTE applies the GTE predicate on the "ended_at" field.

func EndedAtIn

func EndedAtIn(vs ...time.Time) predicate.Session

EndedAtIn applies the In predicate on the "ended_at" field.

func EndedAtIsNil

func EndedAtIsNil() predicate.Session

EndedAtIsNil applies the IsNil predicate on the "ended_at" field.

func EndedAtLT

func EndedAtLT(v time.Time) predicate.Session

EndedAtLT applies the LT predicate on the "ended_at" field.

func EndedAtLTE

func EndedAtLTE(v time.Time) predicate.Session

EndedAtLTE applies the LTE predicate on the "ended_at" field.

func EndedAtNEQ

func EndedAtNEQ(v time.Time) predicate.Session

EndedAtNEQ applies the NEQ predicate on the "ended_at" field.

func EndedAtNotIn

func EndedAtNotIn(vs ...time.Time) predicate.Session

EndedAtNotIn applies the NotIn predicate on the "ended_at" field.

func EndedAtNotNil

func EndedAtNotNil() predicate.Session

EndedAtNotNil applies the NotNil predicate on the "ended_at" field.

func Errors

func Errors(v int) predicate.Session

Errors applies equality check predicate on the "errors" field. It's identical to ErrorsEQ.

func ErrorsEQ

func ErrorsEQ(v int) predicate.Session

ErrorsEQ applies the EQ predicate on the "errors" field.

func ErrorsGT

func ErrorsGT(v int) predicate.Session

ErrorsGT applies the GT predicate on the "errors" field.

func ErrorsGTE

func ErrorsGTE(v int) predicate.Session

ErrorsGTE applies the GTE predicate on the "errors" field.

func ErrorsIn

func ErrorsIn(vs ...int) predicate.Session

ErrorsIn applies the In predicate on the "errors" field.

func ErrorsLT

func ErrorsLT(v int) predicate.Session

ErrorsLT applies the LT predicate on the "errors" field.

func ErrorsLTE

func ErrorsLTE(v int) predicate.Session

ErrorsLTE applies the LTE predicate on the "errors" field.

func ErrorsNEQ

func ErrorsNEQ(v int) predicate.Session

ErrorsNEQ applies the NEQ predicate on the "errors" field.

func ErrorsNotIn

func ErrorsNotIn(vs ...int) predicate.Session

ErrorsNotIn applies the NotIn predicate on the "errors" field.

func EstimatedCostUsd added in v0.4.0

func EstimatedCostUsd(v float64) predicate.Session

EstimatedCostUsd applies equality check predicate on the "estimated_cost_usd" field. It's identical to EstimatedCostUsdEQ.

func EstimatedCostUsdEQ added in v0.4.0

func EstimatedCostUsdEQ(v float64) predicate.Session

EstimatedCostUsdEQ applies the EQ predicate on the "estimated_cost_usd" field.

func EstimatedCostUsdGT added in v0.4.0

func EstimatedCostUsdGT(v float64) predicate.Session

EstimatedCostUsdGT applies the GT predicate on the "estimated_cost_usd" field.

func EstimatedCostUsdGTE added in v0.4.0

func EstimatedCostUsdGTE(v float64) predicate.Session

EstimatedCostUsdGTE applies the GTE predicate on the "estimated_cost_usd" field.

func EstimatedCostUsdIn added in v0.4.0

func EstimatedCostUsdIn(vs ...float64) predicate.Session

EstimatedCostUsdIn applies the In predicate on the "estimated_cost_usd" field.

func EstimatedCostUsdLT added in v0.4.0

func EstimatedCostUsdLT(v float64) predicate.Session

EstimatedCostUsdLT applies the LT predicate on the "estimated_cost_usd" field.

func EstimatedCostUsdLTE added in v0.4.0

func EstimatedCostUsdLTE(v float64) predicate.Session

EstimatedCostUsdLTE applies the LTE predicate on the "estimated_cost_usd" field.

func EstimatedCostUsdNEQ added in v0.4.0

func EstimatedCostUsdNEQ(v float64) predicate.Session

EstimatedCostUsdNEQ applies the NEQ predicate on the "estimated_cost_usd" field.

func EstimatedCostUsdNotIn added in v0.4.0

func EstimatedCostUsdNotIn(vs ...float64) predicate.Session

EstimatedCostUsdNotIn applies the NotIn predicate on the "estimated_cost_usd" field.

func FilesRead

func FilesRead(v int) predicate.Session

FilesRead applies equality check predicate on the "files_read" field. It's identical to FilesReadEQ.

func FilesReadEQ

func FilesReadEQ(v int) predicate.Session

FilesReadEQ applies the EQ predicate on the "files_read" field.

func FilesReadGT

func FilesReadGT(v int) predicate.Session

FilesReadGT applies the GT predicate on the "files_read" field.

func FilesReadGTE

func FilesReadGTE(v int) predicate.Session

FilesReadGTE applies the GTE predicate on the "files_read" field.

func FilesReadIn

func FilesReadIn(vs ...int) predicate.Session

FilesReadIn applies the In predicate on the "files_read" field.

func FilesReadLT

func FilesReadLT(v int) predicate.Session

FilesReadLT applies the LT predicate on the "files_read" field.

func FilesReadLTE

func FilesReadLTE(v int) predicate.Session

FilesReadLTE applies the LTE predicate on the "files_read" field.

func FilesReadNEQ

func FilesReadNEQ(v int) predicate.Session

FilesReadNEQ applies the NEQ predicate on the "files_read" field.

func FilesReadNotIn

func FilesReadNotIn(vs ...int) predicate.Session

FilesReadNotIn applies the NotIn predicate on the "files_read" field.

func FilesWritten

func FilesWritten(v int) predicate.Session

FilesWritten applies equality check predicate on the "files_written" field. It's identical to FilesWrittenEQ.

func FilesWrittenEQ

func FilesWrittenEQ(v int) predicate.Session

FilesWrittenEQ applies the EQ predicate on the "files_written" field.

func FilesWrittenGT

func FilesWrittenGT(v int) predicate.Session

FilesWrittenGT applies the GT predicate on the "files_written" field.

func FilesWrittenGTE

func FilesWrittenGTE(v int) predicate.Session

FilesWrittenGTE applies the GTE predicate on the "files_written" field.

func FilesWrittenIn

func FilesWrittenIn(vs ...int) predicate.Session

FilesWrittenIn applies the In predicate on the "files_written" field.

func FilesWrittenLT

func FilesWrittenLT(v int) predicate.Session

FilesWrittenLT applies the LT predicate on the "files_written" field.

func FilesWrittenLTE

func FilesWrittenLTE(v int) predicate.Session

FilesWrittenLTE applies the LTE predicate on the "files_written" field.

func FilesWrittenNEQ

func FilesWrittenNEQ(v int) predicate.Session

FilesWrittenNEQ applies the NEQ predicate on the "files_written" field.

func FilesWrittenNotIn

func FilesWrittenNotIn(vs ...int) predicate.Session

FilesWrittenNotIn applies the NotIn predicate on the "files_written" field.

func HasEvents

func HasEvents() predicate.Session

HasEvents applies the HasEdge predicate on the "events" edge.

func HasEventsWith

func HasEventsWith(preds ...predicate.AuditEvent) predicate.Session

HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Session

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Session

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Session

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Session

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Session

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Session

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Session

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Session

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Session

IDNotIn applies the NotIn predicate on the ID field.

func InputTokens added in v0.4.0

func InputTokens(v int64) predicate.Session

InputTokens applies equality check predicate on the "input_tokens" field. It's identical to InputTokensEQ.

func InputTokensEQ added in v0.4.0

func InputTokensEQ(v int64) predicate.Session

InputTokensEQ applies the EQ predicate on the "input_tokens" field.

func InputTokensGT added in v0.4.0

func InputTokensGT(v int64) predicate.Session

InputTokensGT applies the GT predicate on the "input_tokens" field.

func InputTokensGTE added in v0.4.0

func InputTokensGTE(v int64) predicate.Session

InputTokensGTE applies the GTE predicate on the "input_tokens" field.

func InputTokensIn added in v0.4.0

func InputTokensIn(vs ...int64) predicate.Session

InputTokensIn applies the In predicate on the "input_tokens" field.

func InputTokensLT added in v0.4.0

func InputTokensLT(v int64) predicate.Session

InputTokensLT applies the LT predicate on the "input_tokens" field.

func InputTokensLTE added in v0.4.0

func InputTokensLTE(v int64) predicate.Session

InputTokensLTE applies the LTE predicate on the "input_tokens" field.

func InputTokensNEQ added in v0.4.0

func InputTokensNEQ(v int64) predicate.Session

InputTokensNEQ applies the NEQ predicate on the "input_tokens" field.

func InputTokensNotIn added in v0.4.0

func InputTokensNotIn(vs ...int64) predicate.Session

InputTokensNotIn applies the NotIn predicate on the "input_tokens" field.

func ModelUsageIsNil added in v0.4.0

func ModelUsageIsNil() predicate.Session

ModelUsageIsNil applies the IsNil predicate on the "model_usage" field.

func ModelUsageNotNil added in v0.4.0

func ModelUsageNotNil() predicate.Session

ModelUsageNotNil applies the NotNil predicate on the "model_usage" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Session) predicate.Session

Or groups predicates with the OR operator between them.

func OutputTokens added in v0.4.0

func OutputTokens(v int64) predicate.Session

OutputTokens applies equality check predicate on the "output_tokens" field. It's identical to OutputTokensEQ.

func OutputTokensEQ added in v0.4.0

func OutputTokensEQ(v int64) predicate.Session

OutputTokensEQ applies the EQ predicate on the "output_tokens" field.

func OutputTokensGT added in v0.4.0

func OutputTokensGT(v int64) predicate.Session

OutputTokensGT applies the GT predicate on the "output_tokens" field.

func OutputTokensGTE added in v0.4.0

func OutputTokensGTE(v int64) predicate.Session

OutputTokensGTE applies the GTE predicate on the "output_tokens" field.

func OutputTokensIn added in v0.4.0

func OutputTokensIn(vs ...int64) predicate.Session

OutputTokensIn applies the In predicate on the "output_tokens" field.

func OutputTokensLT added in v0.4.0

func OutputTokensLT(v int64) predicate.Session

OutputTokensLT applies the LT predicate on the "output_tokens" field.

func OutputTokensLTE added in v0.4.0

func OutputTokensLTE(v int64) predicate.Session

OutputTokensLTE applies the LTE predicate on the "output_tokens" field.

func OutputTokensNEQ added in v0.4.0

func OutputTokensNEQ(v int64) predicate.Session

OutputTokensNEQ applies the NEQ predicate on the "output_tokens" field.

func OutputTokensNotIn added in v0.4.0

func OutputTokensNotIn(vs ...int64) predicate.Session

OutputTokensNotIn applies the NotIn predicate on the "output_tokens" field.

func ProjectName

func ProjectName(v string) predicate.Session

ProjectName applies equality check predicate on the "project_name" field. It's identical to ProjectNameEQ.

func ProjectNameContains

func ProjectNameContains(v string) predicate.Session

ProjectNameContains applies the Contains predicate on the "project_name" field.

func ProjectNameContainsFold

func ProjectNameContainsFold(v string) predicate.Session

ProjectNameContainsFold applies the ContainsFold predicate on the "project_name" field.

func ProjectNameEQ

func ProjectNameEQ(v string) predicate.Session

ProjectNameEQ applies the EQ predicate on the "project_name" field.

func ProjectNameEqualFold

func ProjectNameEqualFold(v string) predicate.Session

ProjectNameEqualFold applies the EqualFold predicate on the "project_name" field.

func ProjectNameGT

func ProjectNameGT(v string) predicate.Session

ProjectNameGT applies the GT predicate on the "project_name" field.

func ProjectNameGTE

func ProjectNameGTE(v string) predicate.Session

ProjectNameGTE applies the GTE predicate on the "project_name" field.

func ProjectNameHasPrefix

func ProjectNameHasPrefix(v string) predicate.Session

ProjectNameHasPrefix applies the HasPrefix predicate on the "project_name" field.

func ProjectNameHasSuffix

func ProjectNameHasSuffix(v string) predicate.Session

ProjectNameHasSuffix applies the HasSuffix predicate on the "project_name" field.

func ProjectNameIn

func ProjectNameIn(vs ...string) predicate.Session

ProjectNameIn applies the In predicate on the "project_name" field.

func ProjectNameIsNil

func ProjectNameIsNil() predicate.Session

ProjectNameIsNil applies the IsNil predicate on the "project_name" field.

func ProjectNameLT

func ProjectNameLT(v string) predicate.Session

ProjectNameLT applies the LT predicate on the "project_name" field.

func ProjectNameLTE

func ProjectNameLTE(v string) predicate.Session

ProjectNameLTE applies the LTE predicate on the "project_name" field.

func ProjectNameNEQ

func ProjectNameNEQ(v string) predicate.Session

ProjectNameNEQ applies the NEQ predicate on the "project_name" field.

func ProjectNameNotIn

func ProjectNameNotIn(vs ...string) predicate.Session

ProjectNameNotIn applies the NotIn predicate on the "project_name" field.

func ProjectNameNotNil

func ProjectNameNotNil() predicate.Session

ProjectNameNotNil applies the NotNil predicate on the "project_name" field.

func SensitiveActions added in v0.5.0

func SensitiveActions(v int) predicate.Session

SensitiveActions applies equality check predicate on the "sensitive_actions" field. It's identical to SensitiveActionsEQ.

func SensitiveActionsEQ added in v0.5.0

func SensitiveActionsEQ(v int) predicate.Session

SensitiveActionsEQ applies the EQ predicate on the "sensitive_actions" field.

func SensitiveActionsGT added in v0.5.0

func SensitiveActionsGT(v int) predicate.Session

SensitiveActionsGT applies the GT predicate on the "sensitive_actions" field.

func SensitiveActionsGTE added in v0.5.0

func SensitiveActionsGTE(v int) predicate.Session

SensitiveActionsGTE applies the GTE predicate on the "sensitive_actions" field.

func SensitiveActionsIn added in v0.5.0

func SensitiveActionsIn(vs ...int) predicate.Session

SensitiveActionsIn applies the In predicate on the "sensitive_actions" field.

func SensitiveActionsLT added in v0.5.0

func SensitiveActionsLT(v int) predicate.Session

SensitiveActionsLT applies the LT predicate on the "sensitive_actions" field.

func SensitiveActionsLTE added in v0.5.0

func SensitiveActionsLTE(v int) predicate.Session

SensitiveActionsLTE applies the LTE predicate on the "sensitive_actions" field.

func SensitiveActionsNEQ added in v0.5.0

func SensitiveActionsNEQ(v int) predicate.Session

SensitiveActionsNEQ applies the NEQ predicate on the "sensitive_actions" field.

func SensitiveActionsNotIn added in v0.5.0

func SensitiveActionsNotIn(vs ...int) predicate.Session

SensitiveActionsNotIn applies the NotIn predicate on the "sensitive_actions" field.

func StartedAt

func StartedAt(v time.Time) predicate.Session

StartedAt applies equality check predicate on the "started_at" field. It's identical to StartedAtEQ.

func StartedAtEQ

func StartedAtEQ(v time.Time) predicate.Session

StartedAtEQ applies the EQ predicate on the "started_at" field.

func StartedAtGT

func StartedAtGT(v time.Time) predicate.Session

StartedAtGT applies the GT predicate on the "started_at" field.

func StartedAtGTE

func StartedAtGTE(v time.Time) predicate.Session

StartedAtGTE applies the GTE predicate on the "started_at" field.

func StartedAtIn

func StartedAtIn(vs ...time.Time) predicate.Session

StartedAtIn applies the In predicate on the "started_at" field.

func StartedAtLT

func StartedAtLT(v time.Time) predicate.Session

StartedAtLT applies the LT predicate on the "started_at" field.

func StartedAtLTE

func StartedAtLTE(v time.Time) predicate.Session

StartedAtLTE applies the LTE predicate on the "started_at" field.

func StartedAtNEQ

func StartedAtNEQ(v time.Time) predicate.Session

StartedAtNEQ applies the NEQ predicate on the "started_at" field.

func StartedAtNotIn

func StartedAtNotIn(vs ...time.Time) predicate.Session

StartedAtNotIn applies the NotIn predicate on the "started_at" field.

func TotalActions

func TotalActions(v int) predicate.Session

TotalActions applies equality check predicate on the "total_actions" field. It's identical to TotalActionsEQ.

func TotalActionsEQ

func TotalActionsEQ(v int) predicate.Session

TotalActionsEQ applies the EQ predicate on the "total_actions" field.

func TotalActionsGT

func TotalActionsGT(v int) predicate.Session

TotalActionsGT applies the GT predicate on the "total_actions" field.

func TotalActionsGTE

func TotalActionsGTE(v int) predicate.Session

TotalActionsGTE applies the GTE predicate on the "total_actions" field.

func TotalActionsIn

func TotalActionsIn(vs ...int) predicate.Session

TotalActionsIn applies the In predicate on the "total_actions" field.

func TotalActionsLT

func TotalActionsLT(v int) predicate.Session

TotalActionsLT applies the LT predicate on the "total_actions" field.

func TotalActionsLTE

func TotalActionsLTE(v int) predicate.Session

TotalActionsLTE applies the LTE predicate on the "total_actions" field.

func TotalActionsNEQ

func TotalActionsNEQ(v int) predicate.Session

TotalActionsNEQ applies the NEQ predicate on the "total_actions" field.

func TotalActionsNotIn

func TotalActionsNotIn(vs ...int) predicate.Session

TotalActionsNotIn applies the NotIn predicate on the "total_actions" field.

func TranscriptPath added in v0.4.0

func TranscriptPath(v string) predicate.Session

TranscriptPath applies equality check predicate on the "transcript_path" field. It's identical to TranscriptPathEQ.

func TranscriptPathContains added in v0.4.0

func TranscriptPathContains(v string) predicate.Session

TranscriptPathContains applies the Contains predicate on the "transcript_path" field.

func TranscriptPathContainsFold added in v0.4.0

func TranscriptPathContainsFold(v string) predicate.Session

TranscriptPathContainsFold applies the ContainsFold predicate on the "transcript_path" field.

func TranscriptPathEQ added in v0.4.0

func TranscriptPathEQ(v string) predicate.Session

TranscriptPathEQ applies the EQ predicate on the "transcript_path" field.

func TranscriptPathEqualFold added in v0.4.0

func TranscriptPathEqualFold(v string) predicate.Session

TranscriptPathEqualFold applies the EqualFold predicate on the "transcript_path" field.

func TranscriptPathGT added in v0.4.0

func TranscriptPathGT(v string) predicate.Session

TranscriptPathGT applies the GT predicate on the "transcript_path" field.

func TranscriptPathGTE added in v0.4.0

func TranscriptPathGTE(v string) predicate.Session

TranscriptPathGTE applies the GTE predicate on the "transcript_path" field.

func TranscriptPathHasPrefix added in v0.4.0

func TranscriptPathHasPrefix(v string) predicate.Session

TranscriptPathHasPrefix applies the HasPrefix predicate on the "transcript_path" field.

func TranscriptPathHasSuffix added in v0.4.0

func TranscriptPathHasSuffix(v string) predicate.Session

TranscriptPathHasSuffix applies the HasSuffix predicate on the "transcript_path" field.

func TranscriptPathIn added in v0.4.0

func TranscriptPathIn(vs ...string) predicate.Session

TranscriptPathIn applies the In predicate on the "transcript_path" field.

func TranscriptPathIsNil added in v0.4.0

func TranscriptPathIsNil() predicate.Session

TranscriptPathIsNil applies the IsNil predicate on the "transcript_path" field.

func TranscriptPathLT added in v0.4.0

func TranscriptPathLT(v string) predicate.Session

TranscriptPathLT applies the LT predicate on the "transcript_path" field.

func TranscriptPathLTE added in v0.4.0

func TranscriptPathLTE(v string) predicate.Session

TranscriptPathLTE applies the LTE predicate on the "transcript_path" field.

func TranscriptPathNEQ added in v0.4.0

func TranscriptPathNEQ(v string) predicate.Session

TranscriptPathNEQ applies the NEQ predicate on the "transcript_path" field.

func TranscriptPathNotIn added in v0.4.0

func TranscriptPathNotIn(vs ...string) predicate.Session

TranscriptPathNotIn applies the NotIn predicate on the "transcript_path" field.

func TranscriptPathNotNil added in v0.4.0

func TranscriptPathNotNil() predicate.Session

TranscriptPathNotNil applies the NotNil predicate on the "transcript_path" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WorkingDirectory

func WorkingDirectory(v string) predicate.Session

WorkingDirectory applies equality check predicate on the "working_directory" field. It's identical to WorkingDirectoryEQ.

func WorkingDirectoryContains

func WorkingDirectoryContains(v string) predicate.Session

WorkingDirectoryContains applies the Contains predicate on the "working_directory" field.

func WorkingDirectoryContainsFold

func WorkingDirectoryContainsFold(v string) predicate.Session

WorkingDirectoryContainsFold applies the ContainsFold predicate on the "working_directory" field.

func WorkingDirectoryEQ

func WorkingDirectoryEQ(v string) predicate.Session

WorkingDirectoryEQ applies the EQ predicate on the "working_directory" field.

func WorkingDirectoryEqualFold

func WorkingDirectoryEqualFold(v string) predicate.Session

WorkingDirectoryEqualFold applies the EqualFold predicate on the "working_directory" field.

func WorkingDirectoryGT

func WorkingDirectoryGT(v string) predicate.Session

WorkingDirectoryGT applies the GT predicate on the "working_directory" field.

func WorkingDirectoryGTE

func WorkingDirectoryGTE(v string) predicate.Session

WorkingDirectoryGTE applies the GTE predicate on the "working_directory" field.

func WorkingDirectoryHasPrefix

func WorkingDirectoryHasPrefix(v string) predicate.Session

WorkingDirectoryHasPrefix applies the HasPrefix predicate on the "working_directory" field.

func WorkingDirectoryHasSuffix

func WorkingDirectoryHasSuffix(v string) predicate.Session

WorkingDirectoryHasSuffix applies the HasSuffix predicate on the "working_directory" field.

func WorkingDirectoryIn

func WorkingDirectoryIn(vs ...string) predicate.Session

WorkingDirectoryIn applies the In predicate on the "working_directory" field.

func WorkingDirectoryIsNil

func WorkingDirectoryIsNil() predicate.Session

WorkingDirectoryIsNil applies the IsNil predicate on the "working_directory" field.

func WorkingDirectoryLT

func WorkingDirectoryLT(v string) predicate.Session

WorkingDirectoryLT applies the LT predicate on the "working_directory" field.

func WorkingDirectoryLTE

func WorkingDirectoryLTE(v string) predicate.Session

WorkingDirectoryLTE applies the LTE predicate on the "working_directory" field.

func WorkingDirectoryNEQ

func WorkingDirectoryNEQ(v string) predicate.Session

WorkingDirectoryNEQ applies the NEQ predicate on the "working_directory" field.

func WorkingDirectoryNotIn

func WorkingDirectoryNotIn(vs ...string) predicate.Session

WorkingDirectoryNotIn applies the NotIn predicate on the "working_directory" field.

func WorkingDirectoryNotNil

func WorkingDirectoryNotNil() predicate.Session

WorkingDirectoryNotNil applies the NotNil predicate on the "working_directory" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Session queries.

func ByAgentName

func ByAgentName(opts ...sql.OrderTermOption) OrderOption

ByAgentName orders the results by the agent_name field.

func ByAgentSessionID

func ByAgentSessionID(opts ...sql.OrderTermOption) OrderOption

ByAgentSessionID orders the results by the agent_session_id field.

func ByAgentVersion

func ByAgentVersion(opts ...sql.OrderTermOption) OrderOption

ByAgentVersion orders the results by the agent_version field.

func ByBlockedActions added in v0.5.0

func ByBlockedActions(opts ...sql.OrderTermOption) OrderOption

ByBlockedActions orders the results by the blocked_actions field.

func ByCacheReadTokens added in v0.4.0

func ByCacheReadTokens(opts ...sql.OrderTermOption) OrderOption

ByCacheReadTokens orders the results by the cache_read_tokens field.

func ByCacheWriteTokens added in v0.4.0

func ByCacheWriteTokens(opts ...sql.OrderTermOption) OrderOption

ByCacheWriteTokens orders the results by the cache_write_tokens field.

func ByCommandsExecuted

func ByCommandsExecuted(opts ...sql.OrderTermOption) OrderOption

ByCommandsExecuted orders the results by the commands_executed field.

func ByCostComputedAt added in v0.4.0

func ByCostComputedAt(opts ...sql.OrderTermOption) OrderOption

ByCostComputedAt orders the results by the cost_computed_at field.

func ByCostSource added in v0.4.0

func ByCostSource(opts ...sql.OrderTermOption) OrderOption

ByCostSource orders the results by the cost_source field.

func ByEndedAt

func ByEndedAt(opts ...sql.OrderTermOption) OrderOption

ByEndedAt orders the results by the ended_at field.

func ByErrors

func ByErrors(opts ...sql.OrderTermOption) OrderOption

ByErrors orders the results by the errors field.

func ByEstimatedCostUsd added in v0.4.0

func ByEstimatedCostUsd(opts ...sql.OrderTermOption) OrderOption

ByEstimatedCostUsd orders the results by the estimated_cost_usd field.

func ByEvents

func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEvents orders the results by events terms.

func ByEventsCount

func ByEventsCount(opts ...sql.OrderTermOption) OrderOption

ByEventsCount orders the results by events count.

func ByFilesRead

func ByFilesRead(opts ...sql.OrderTermOption) OrderOption

ByFilesRead orders the results by the files_read field.

func ByFilesWritten

func ByFilesWritten(opts ...sql.OrderTermOption) OrderOption

ByFilesWritten orders the results by the files_written field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByInputTokens added in v0.4.0

func ByInputTokens(opts ...sql.OrderTermOption) OrderOption

ByInputTokens orders the results by the input_tokens field.

func ByOutputTokens added in v0.4.0

func ByOutputTokens(opts ...sql.OrderTermOption) OrderOption

ByOutputTokens orders the results by the output_tokens field.

func ByProjectName

func ByProjectName(opts ...sql.OrderTermOption) OrderOption

ByProjectName orders the results by the project_name field.

func BySensitiveActions added in v0.5.0

func BySensitiveActions(opts ...sql.OrderTermOption) OrderOption

BySensitiveActions orders the results by the sensitive_actions field.

func ByStartedAt

func ByStartedAt(opts ...sql.OrderTermOption) OrderOption

ByStartedAt orders the results by the started_at field.

func ByTotalActions

func ByTotalActions(opts ...sql.OrderTermOption) OrderOption

ByTotalActions orders the results by the total_actions field.

func ByTranscriptPath added in v0.4.0

func ByTranscriptPath(opts ...sql.OrderTermOption) OrderOption

ByTranscriptPath orders the results by the transcript_path field.

func ByWorkingDirectory

func ByWorkingDirectory(opts ...sql.OrderTermOption) OrderOption

ByWorkingDirectory orders the results by the working_directory field.

Jump to