Documentation
¶
Index ¶
- Constants
- Variables
- func AgentName(v string) predicate.Session
- func AgentNameContains(v string) predicate.Session
- func AgentNameContainsFold(v string) predicate.Session
- func AgentNameEQ(v string) predicate.Session
- func AgentNameEqualFold(v string) predicate.Session
- func AgentNameGT(v string) predicate.Session
- func AgentNameGTE(v string) predicate.Session
- func AgentNameHasPrefix(v string) predicate.Session
- func AgentNameHasSuffix(v string) predicate.Session
- func AgentNameIn(vs ...string) predicate.Session
- func AgentNameLT(v string) predicate.Session
- func AgentNameLTE(v string) predicate.Session
- func AgentNameNEQ(v string) predicate.Session
- func AgentNameNotIn(vs ...string) predicate.Session
- func AgentSessionID(v string) predicate.Session
- func AgentSessionIDContains(v string) predicate.Session
- func AgentSessionIDContainsFold(v string) predicate.Session
- func AgentSessionIDEQ(v string) predicate.Session
- func AgentSessionIDEqualFold(v string) predicate.Session
- func AgentSessionIDGT(v string) predicate.Session
- func AgentSessionIDGTE(v string) predicate.Session
- func AgentSessionIDHasPrefix(v string) predicate.Session
- func AgentSessionIDHasSuffix(v string) predicate.Session
- func AgentSessionIDIn(vs ...string) predicate.Session
- func AgentSessionIDIsNil() predicate.Session
- func AgentSessionIDLT(v string) predicate.Session
- func AgentSessionIDLTE(v string) predicate.Session
- func AgentSessionIDNEQ(v string) predicate.Session
- func AgentSessionIDNotIn(vs ...string) predicate.Session
- func AgentSessionIDNotNil() predicate.Session
- func AgentVersion(v string) predicate.Session
- func AgentVersionContains(v string) predicate.Session
- func AgentVersionContainsFold(v string) predicate.Session
- func AgentVersionEQ(v string) predicate.Session
- func AgentVersionEqualFold(v string) predicate.Session
- func AgentVersionGT(v string) predicate.Session
- func AgentVersionGTE(v string) predicate.Session
- func AgentVersionHasPrefix(v string) predicate.Session
- func AgentVersionHasSuffix(v string) predicate.Session
- func AgentVersionIn(vs ...string) predicate.Session
- func AgentVersionIsNil() predicate.Session
- func AgentVersionLT(v string) predicate.Session
- func AgentVersionLTE(v string) predicate.Session
- func AgentVersionNEQ(v string) predicate.Session
- func AgentVersionNotIn(vs ...string) predicate.Session
- func AgentVersionNotNil() predicate.Session
- func And(predicates ...predicate.Session) predicate.Session
- func BlockedActions(v int) predicate.Session
- func BlockedActionsEQ(v int) predicate.Session
- func BlockedActionsGT(v int) predicate.Session
- func BlockedActionsGTE(v int) predicate.Session
- func BlockedActionsIn(vs ...int) predicate.Session
- func BlockedActionsLT(v int) predicate.Session
- func BlockedActionsLTE(v int) predicate.Session
- func BlockedActionsNEQ(v int) predicate.Session
- func BlockedActionsNotIn(vs ...int) predicate.Session
- func CacheReadTokens(v int64) predicate.Session
- func CacheReadTokensEQ(v int64) predicate.Session
- func CacheReadTokensGT(v int64) predicate.Session
- func CacheReadTokensGTE(v int64) predicate.Session
- func CacheReadTokensIn(vs ...int64) predicate.Session
- func CacheReadTokensLT(v int64) predicate.Session
- func CacheReadTokensLTE(v int64) predicate.Session
- func CacheReadTokensNEQ(v int64) predicate.Session
- func CacheReadTokensNotIn(vs ...int64) predicate.Session
- func CacheWriteTokens(v int64) predicate.Session
- func CacheWriteTokensEQ(v int64) predicate.Session
- func CacheWriteTokensGT(v int64) predicate.Session
- func CacheWriteTokensGTE(v int64) predicate.Session
- func CacheWriteTokensIn(vs ...int64) predicate.Session
- func CacheWriteTokensLT(v int64) predicate.Session
- func CacheWriteTokensLTE(v int64) predicate.Session
- func CacheWriteTokensNEQ(v int64) predicate.Session
- func CacheWriteTokensNotIn(vs ...int64) predicate.Session
- func CommandsExecuted(v int) predicate.Session
- func CommandsExecutedEQ(v int) predicate.Session
- func CommandsExecutedGT(v int) predicate.Session
- func CommandsExecutedGTE(v int) predicate.Session
- func CommandsExecutedIn(vs ...int) predicate.Session
- func CommandsExecutedLT(v int) predicate.Session
- func CommandsExecutedLTE(v int) predicate.Session
- func CommandsExecutedNEQ(v int) predicate.Session
- func CommandsExecutedNotIn(vs ...int) predicate.Session
- func CostComputedAt(v time.Time) predicate.Session
- func CostComputedAtEQ(v time.Time) predicate.Session
- func CostComputedAtGT(v time.Time) predicate.Session
- func CostComputedAtGTE(v time.Time) predicate.Session
- func CostComputedAtIn(vs ...time.Time) predicate.Session
- func CostComputedAtIsNil() predicate.Session
- func CostComputedAtLT(v time.Time) predicate.Session
- func CostComputedAtLTE(v time.Time) predicate.Session
- func CostComputedAtNEQ(v time.Time) predicate.Session
- func CostComputedAtNotIn(vs ...time.Time) predicate.Session
- func CostComputedAtNotNil() predicate.Session
- func CostSource(v string) predicate.Session
- func CostSourceContains(v string) predicate.Session
- func CostSourceContainsFold(v string) predicate.Session
- func CostSourceEQ(v string) predicate.Session
- func CostSourceEqualFold(v string) predicate.Session
- func CostSourceGT(v string) predicate.Session
- func CostSourceGTE(v string) predicate.Session
- func CostSourceHasPrefix(v string) predicate.Session
- func CostSourceHasSuffix(v string) predicate.Session
- func CostSourceIn(vs ...string) predicate.Session
- func CostSourceIsNil() predicate.Session
- func CostSourceLT(v string) predicate.Session
- func CostSourceLTE(v string) predicate.Session
- func CostSourceNEQ(v string) predicate.Session
- func CostSourceNotIn(vs ...string) predicate.Session
- func CostSourceNotNil() predicate.Session
- func EndedAt(v time.Time) predicate.Session
- func EndedAtEQ(v time.Time) predicate.Session
- func EndedAtGT(v time.Time) predicate.Session
- func EndedAtGTE(v time.Time) predicate.Session
- func EndedAtIn(vs ...time.Time) predicate.Session
- func EndedAtIsNil() predicate.Session
- func EndedAtLT(v time.Time) predicate.Session
- func EndedAtLTE(v time.Time) predicate.Session
- func EndedAtNEQ(v time.Time) predicate.Session
- func EndedAtNotIn(vs ...time.Time) predicate.Session
- func EndedAtNotNil() predicate.Session
- func Errors(v int) predicate.Session
- func ErrorsEQ(v int) predicate.Session
- func ErrorsGT(v int) predicate.Session
- func ErrorsGTE(v int) predicate.Session
- func ErrorsIn(vs ...int) predicate.Session
- func ErrorsLT(v int) predicate.Session
- func ErrorsLTE(v int) predicate.Session
- func ErrorsNEQ(v int) predicate.Session
- func ErrorsNotIn(vs ...int) predicate.Session
- func EstimatedCostUsd(v float64) predicate.Session
- func EstimatedCostUsdEQ(v float64) predicate.Session
- func EstimatedCostUsdGT(v float64) predicate.Session
- func EstimatedCostUsdGTE(v float64) predicate.Session
- func EstimatedCostUsdIn(vs ...float64) predicate.Session
- func EstimatedCostUsdLT(v float64) predicate.Session
- func EstimatedCostUsdLTE(v float64) predicate.Session
- func EstimatedCostUsdNEQ(v float64) predicate.Session
- func EstimatedCostUsdNotIn(vs ...float64) predicate.Session
- func FilesRead(v int) predicate.Session
- func FilesReadEQ(v int) predicate.Session
- func FilesReadGT(v int) predicate.Session
- func FilesReadGTE(v int) predicate.Session
- func FilesReadIn(vs ...int) predicate.Session
- func FilesReadLT(v int) predicate.Session
- func FilesReadLTE(v int) predicate.Session
- func FilesReadNEQ(v int) predicate.Session
- func FilesReadNotIn(vs ...int) predicate.Session
- func FilesWritten(v int) predicate.Session
- func FilesWrittenEQ(v int) predicate.Session
- func FilesWrittenGT(v int) predicate.Session
- func FilesWrittenGTE(v int) predicate.Session
- func FilesWrittenIn(vs ...int) predicate.Session
- func FilesWrittenLT(v int) predicate.Session
- func FilesWrittenLTE(v int) predicate.Session
- func FilesWrittenNEQ(v int) predicate.Session
- func FilesWrittenNotIn(vs ...int) predicate.Session
- func HasEvents() predicate.Session
- func HasEventsWith(preds ...predicate.AuditEvent) predicate.Session
- func ID(id uuid.UUID) predicate.Session
- func IDEQ(id uuid.UUID) predicate.Session
- func IDGT(id uuid.UUID) predicate.Session
- func IDGTE(id uuid.UUID) predicate.Session
- func IDIn(ids ...uuid.UUID) predicate.Session
- func IDLT(id uuid.UUID) predicate.Session
- func IDLTE(id uuid.UUID) predicate.Session
- func IDNEQ(id uuid.UUID) predicate.Session
- func IDNotIn(ids ...uuid.UUID) predicate.Session
- func InputTokens(v int64) predicate.Session
- func InputTokensEQ(v int64) predicate.Session
- func InputTokensGT(v int64) predicate.Session
- func InputTokensGTE(v int64) predicate.Session
- func InputTokensIn(vs ...int64) predicate.Session
- func InputTokensLT(v int64) predicate.Session
- func InputTokensLTE(v int64) predicate.Session
- func InputTokensNEQ(v int64) predicate.Session
- func InputTokensNotIn(vs ...int64) predicate.Session
- func ModelUsageIsNil() predicate.Session
- func ModelUsageNotNil() predicate.Session
- func Not(p predicate.Session) predicate.Session
- func Or(predicates ...predicate.Session) predicate.Session
- func OutputTokens(v int64) predicate.Session
- func OutputTokensEQ(v int64) predicate.Session
- func OutputTokensGT(v int64) predicate.Session
- func OutputTokensGTE(v int64) predicate.Session
- func OutputTokensIn(vs ...int64) predicate.Session
- func OutputTokensLT(v int64) predicate.Session
- func OutputTokensLTE(v int64) predicate.Session
- func OutputTokensNEQ(v int64) predicate.Session
- func OutputTokensNotIn(vs ...int64) predicate.Session
- func ProjectName(v string) predicate.Session
- func ProjectNameContains(v string) predicate.Session
- func ProjectNameContainsFold(v string) predicate.Session
- func ProjectNameEQ(v string) predicate.Session
- func ProjectNameEqualFold(v string) predicate.Session
- func ProjectNameGT(v string) predicate.Session
- func ProjectNameGTE(v string) predicate.Session
- func ProjectNameHasPrefix(v string) predicate.Session
- func ProjectNameHasSuffix(v string) predicate.Session
- func ProjectNameIn(vs ...string) predicate.Session
- func ProjectNameIsNil() predicate.Session
- func ProjectNameLT(v string) predicate.Session
- func ProjectNameLTE(v string) predicate.Session
- func ProjectNameNEQ(v string) predicate.Session
- func ProjectNameNotIn(vs ...string) predicate.Session
- func ProjectNameNotNil() predicate.Session
- func SensitiveActions(v int) predicate.Session
- func SensitiveActionsEQ(v int) predicate.Session
- func SensitiveActionsGT(v int) predicate.Session
- func SensitiveActionsGTE(v int) predicate.Session
- func SensitiveActionsIn(vs ...int) predicate.Session
- func SensitiveActionsLT(v int) predicate.Session
- func SensitiveActionsLTE(v int) predicate.Session
- func SensitiveActionsNEQ(v int) predicate.Session
- func SensitiveActionsNotIn(vs ...int) predicate.Session
- func StartedAt(v time.Time) predicate.Session
- func StartedAtEQ(v time.Time) predicate.Session
- func StartedAtGT(v time.Time) predicate.Session
- func StartedAtGTE(v time.Time) predicate.Session
- func StartedAtIn(vs ...time.Time) predicate.Session
- func StartedAtLT(v time.Time) predicate.Session
- func StartedAtLTE(v time.Time) predicate.Session
- func StartedAtNEQ(v time.Time) predicate.Session
- func StartedAtNotIn(vs ...time.Time) predicate.Session
- func TotalActions(v int) predicate.Session
- func TotalActionsEQ(v int) predicate.Session
- func TotalActionsGT(v int) predicate.Session
- func TotalActionsGTE(v int) predicate.Session
- func TotalActionsIn(vs ...int) predicate.Session
- func TotalActionsLT(v int) predicate.Session
- func TotalActionsLTE(v int) predicate.Session
- func TotalActionsNEQ(v int) predicate.Session
- func TotalActionsNotIn(vs ...int) predicate.Session
- func TranscriptPath(v string) predicate.Session
- func TranscriptPathContains(v string) predicate.Session
- func TranscriptPathContainsFold(v string) predicate.Session
- func TranscriptPathEQ(v string) predicate.Session
- func TranscriptPathEqualFold(v string) predicate.Session
- func TranscriptPathGT(v string) predicate.Session
- func TranscriptPathGTE(v string) predicate.Session
- func TranscriptPathHasPrefix(v string) predicate.Session
- func TranscriptPathHasSuffix(v string) predicate.Session
- func TranscriptPathIn(vs ...string) predicate.Session
- func TranscriptPathIsNil() predicate.Session
- func TranscriptPathLT(v string) predicate.Session
- func TranscriptPathLTE(v string) predicate.Session
- func TranscriptPathNEQ(v string) predicate.Session
- func TranscriptPathNotIn(vs ...string) predicate.Session
- func TranscriptPathNotNil() predicate.Session
- func ValidColumn(column string) bool
- func WorkingDirectory(v string) predicate.Session
- func WorkingDirectoryContains(v string) predicate.Session
- func WorkingDirectoryContainsFold(v string) predicate.Session
- func WorkingDirectoryEQ(v string) predicate.Session
- func WorkingDirectoryEqualFold(v string) predicate.Session
- func WorkingDirectoryGT(v string) predicate.Session
- func WorkingDirectoryGTE(v string) predicate.Session
- func WorkingDirectoryHasPrefix(v string) predicate.Session
- func WorkingDirectoryHasSuffix(v string) predicate.Session
- func WorkingDirectoryIn(vs ...string) predicate.Session
- func WorkingDirectoryIsNil() predicate.Session
- func WorkingDirectoryLT(v string) predicate.Session
- func WorkingDirectoryLTE(v string) predicate.Session
- func WorkingDirectoryNEQ(v string) predicate.Session
- func WorkingDirectoryNotIn(vs ...string) predicate.Session
- func WorkingDirectoryNotNil() predicate.Session
- type OrderOption
- func ByAgentName(opts ...sql.OrderTermOption) OrderOption
- func ByAgentSessionID(opts ...sql.OrderTermOption) OrderOption
- func ByAgentVersion(opts ...sql.OrderTermOption) OrderOption
- func ByBlockedActions(opts ...sql.OrderTermOption) OrderOption
- func ByCacheReadTokens(opts ...sql.OrderTermOption) OrderOption
- func ByCacheWriteTokens(opts ...sql.OrderTermOption) OrderOption
- func ByCommandsExecuted(opts ...sql.OrderTermOption) OrderOption
- func ByCostComputedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCostSource(opts ...sql.OrderTermOption) OrderOption
- func ByEndedAt(opts ...sql.OrderTermOption) OrderOption
- func ByErrors(opts ...sql.OrderTermOption) OrderOption
- func ByEstimatedCostUsd(opts ...sql.OrderTermOption) OrderOption
- func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
- func ByFilesRead(opts ...sql.OrderTermOption) OrderOption
- func ByFilesWritten(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByInputTokens(opts ...sql.OrderTermOption) OrderOption
- func ByOutputTokens(opts ...sql.OrderTermOption) OrderOption
- func ByProjectName(opts ...sql.OrderTermOption) OrderOption
- func BySensitiveActions(opts ...sql.OrderTermOption) OrderOption
- func ByStartedAt(opts ...sql.OrderTermOption) OrderOption
- func ByTotalActions(opts ...sql.OrderTermOption) OrderOption
- func ByTranscriptPath(opts ...sql.OrderTermOption) OrderOption
- func ByWorkingDirectory(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the session type in the database. Label = "session" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldAgentSessionID holds the string denoting the agent_session_id field in the database. FieldAgentSessionID = "agent_session_id" // FieldAgentName holds the string denoting the agent_name field in the database. FieldAgentName = "agent_name" // FieldAgentVersion holds the string denoting the agent_version field in the database. FieldAgentVersion = "agent_version" // FieldStartedAt holds the string denoting the started_at field in the database. FieldStartedAt = "started_at" // FieldEndedAt holds the string denoting the ended_at field in the database. FieldEndedAt = "ended_at" // FieldWorkingDirectory holds the string denoting the working_directory field in the database. FieldWorkingDirectory = "working_directory" // FieldProjectName holds the string denoting the project_name field in the database. FieldProjectName = "project_name" // FieldTotalActions holds the string denoting the total_actions field in the database. FieldTotalActions = "total_actions" // FieldFilesRead holds the string denoting the files_read field in the database. FieldFilesRead = "files_read" // FieldFilesWritten holds the string denoting the files_written field in the database. FieldFilesWritten = "files_written" // FieldCommandsExecuted holds the string denoting the commands_executed field in the database. FieldCommandsExecuted = "commands_executed" // FieldErrors holds the string denoting the errors field in the database. FieldErrors = "errors" // FieldSensitiveActions holds the string denoting the sensitive_actions field in the database. FieldSensitiveActions = "sensitive_actions" // FieldBlockedActions holds the string denoting the blocked_actions field in the database. FieldBlockedActions = "blocked_actions" // FieldTranscriptPath holds the string denoting the transcript_path field in the database. FieldTranscriptPath = "transcript_path" // FieldInputTokens holds the string denoting the input_tokens field in the database. FieldInputTokens = "input_tokens" // FieldOutputTokens holds the string denoting the output_tokens field in the database. FieldOutputTokens = "output_tokens" // FieldCacheReadTokens holds the string denoting the cache_read_tokens field in the database. FieldCacheReadTokens = "cache_read_tokens" // FieldCacheWriteTokens holds the string denoting the cache_write_tokens field in the database. FieldCacheWriteTokens = "cache_write_tokens" // FieldEstimatedCostUsd holds the string denoting the estimated_cost_usd field in the database. FieldEstimatedCostUsd = "estimated_cost_usd" // FieldModelUsage holds the string denoting the model_usage field in the database. FieldModelUsage = "model_usage" // FieldCostSource holds the string denoting the cost_source field in the database. FieldCostSource = "cost_source" // FieldCostComputedAt holds the string denoting the cost_computed_at field in the database. FieldCostComputedAt = "cost_computed_at" // EdgeEvents holds the string denoting the events edge name in mutations. EdgeEvents = "events" // Table holds the table name of the session in the database. Table = "sessions" // EventsTable is the table that holds the events relation/edge. EventsTable = "audit_events" // EventsInverseTable is the table name for the AuditEvent entity. // It exists in this package in order to avoid circular dependency with the "auditevent" package. EventsInverseTable = "audit_events" // EventsColumn is the table column denoting the events relation/edge. EventsColumn = "session_id" )
Variables ¶
var ( // AgentNameValidator is a validator for the "agent_name" field. It is called by the builders before save. AgentNameValidator func(string) error // DefaultStartedAt holds the default value on creation for the "started_at" field. DefaultStartedAt func() time.Time // DefaultTotalActions holds the default value on creation for the "total_actions" field. DefaultTotalActions int // DefaultFilesRead holds the default value on creation for the "files_read" field. DefaultFilesRead int // DefaultFilesWritten holds the default value on creation for the "files_written" field. DefaultFilesWritten int // DefaultCommandsExecuted holds the default value on creation for the "commands_executed" field. DefaultCommandsExecuted int // DefaultErrors holds the default value on creation for the "errors" field. DefaultErrors int // DefaultSensitiveActions holds the default value on creation for the "sensitive_actions" field. DefaultSensitiveActions int // DefaultBlockedActions holds the default value on creation for the "blocked_actions" field. DefaultBlockedActions int // DefaultInputTokens holds the default value on creation for the "input_tokens" field. DefaultInputTokens int64 // DefaultOutputTokens holds the default value on creation for the "output_tokens" field. DefaultOutputTokens int64 // DefaultCacheReadTokens holds the default value on creation for the "cache_read_tokens" field. DefaultCacheReadTokens int64 // DefaultCacheWriteTokens holds the default value on creation for the "cache_write_tokens" field. DefaultCacheWriteTokens int64 // DefaultEstimatedCostUsd holds the default value on creation for the "estimated_cost_usd" field. DefaultEstimatedCostUsd float64 // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldAgentSessionID, FieldAgentName, FieldAgentVersion, FieldStartedAt, FieldEndedAt, FieldWorkingDirectory, FieldProjectName, FieldTotalActions, FieldFilesRead, FieldFilesWritten, FieldCommandsExecuted, FieldErrors, FieldSensitiveActions, FieldBlockedActions, FieldTranscriptPath, FieldInputTokens, FieldOutputTokens, FieldCacheReadTokens, FieldCacheWriteTokens, FieldEstimatedCostUsd, FieldModelUsage, FieldCostSource, FieldCostComputedAt, }
Columns holds all SQL columns for session fields.
Functions ¶
func AgentName ¶
AgentName applies equality check predicate on the "agent_name" field. It's identical to AgentNameEQ.
func AgentNameContains ¶
AgentNameContains applies the Contains predicate on the "agent_name" field.
func AgentNameContainsFold ¶
AgentNameContainsFold applies the ContainsFold predicate on the "agent_name" field.
func AgentNameEQ ¶
AgentNameEQ applies the EQ predicate on the "agent_name" field.
func AgentNameEqualFold ¶
AgentNameEqualFold applies the EqualFold predicate on the "agent_name" field.
func AgentNameGT ¶
AgentNameGT applies the GT predicate on the "agent_name" field.
func AgentNameGTE ¶
AgentNameGTE applies the GTE predicate on the "agent_name" field.
func AgentNameHasPrefix ¶
AgentNameHasPrefix applies the HasPrefix predicate on the "agent_name" field.
func AgentNameHasSuffix ¶
AgentNameHasSuffix applies the HasSuffix predicate on the "agent_name" field.
func AgentNameIn ¶
AgentNameIn applies the In predicate on the "agent_name" field.
func AgentNameLT ¶
AgentNameLT applies the LT predicate on the "agent_name" field.
func AgentNameLTE ¶
AgentNameLTE applies the LTE predicate on the "agent_name" field.
func AgentNameNEQ ¶
AgentNameNEQ applies the NEQ predicate on the "agent_name" field.
func AgentNameNotIn ¶
AgentNameNotIn applies the NotIn predicate on the "agent_name" field.
func AgentSessionID ¶
AgentSessionID applies equality check predicate on the "agent_session_id" field. It's identical to AgentSessionIDEQ.
func AgentSessionIDContains ¶
AgentSessionIDContains applies the Contains predicate on the "agent_session_id" field.
func AgentSessionIDContainsFold ¶
AgentSessionIDContainsFold applies the ContainsFold predicate on the "agent_session_id" field.
func AgentSessionIDEQ ¶
AgentSessionIDEQ applies the EQ predicate on the "agent_session_id" field.
func AgentSessionIDEqualFold ¶
AgentSessionIDEqualFold applies the EqualFold predicate on the "agent_session_id" field.
func AgentSessionIDGT ¶
AgentSessionIDGT applies the GT predicate on the "agent_session_id" field.
func AgentSessionIDGTE ¶
AgentSessionIDGTE applies the GTE predicate on the "agent_session_id" field.
func AgentSessionIDHasPrefix ¶
AgentSessionIDHasPrefix applies the HasPrefix predicate on the "agent_session_id" field.
func AgentSessionIDHasSuffix ¶
AgentSessionIDHasSuffix applies the HasSuffix predicate on the "agent_session_id" field.
func AgentSessionIDIn ¶
AgentSessionIDIn applies the In predicate on the "agent_session_id" field.
func AgentSessionIDIsNil ¶
AgentSessionIDIsNil applies the IsNil predicate on the "agent_session_id" field.
func AgentSessionIDLT ¶
AgentSessionIDLT applies the LT predicate on the "agent_session_id" field.
func AgentSessionIDLTE ¶
AgentSessionIDLTE applies the LTE predicate on the "agent_session_id" field.
func AgentSessionIDNEQ ¶
AgentSessionIDNEQ applies the NEQ predicate on the "agent_session_id" field.
func AgentSessionIDNotIn ¶
AgentSessionIDNotIn applies the NotIn predicate on the "agent_session_id" field.
func AgentSessionIDNotNil ¶
AgentSessionIDNotNil applies the NotNil predicate on the "agent_session_id" field.
func AgentVersion ¶
AgentVersion applies equality check predicate on the "agent_version" field. It's identical to AgentVersionEQ.
func AgentVersionContains ¶
AgentVersionContains applies the Contains predicate on the "agent_version" field.
func AgentVersionContainsFold ¶
AgentVersionContainsFold applies the ContainsFold predicate on the "agent_version" field.
func AgentVersionEQ ¶
AgentVersionEQ applies the EQ predicate on the "agent_version" field.
func AgentVersionEqualFold ¶
AgentVersionEqualFold applies the EqualFold predicate on the "agent_version" field.
func AgentVersionGT ¶
AgentVersionGT applies the GT predicate on the "agent_version" field.
func AgentVersionGTE ¶
AgentVersionGTE applies the GTE predicate on the "agent_version" field.
func AgentVersionHasPrefix ¶
AgentVersionHasPrefix applies the HasPrefix predicate on the "agent_version" field.
func AgentVersionHasSuffix ¶
AgentVersionHasSuffix applies the HasSuffix predicate on the "agent_version" field.
func AgentVersionIn ¶
AgentVersionIn applies the In predicate on the "agent_version" field.
func AgentVersionIsNil ¶
AgentVersionIsNil applies the IsNil predicate on the "agent_version" field.
func AgentVersionLT ¶
AgentVersionLT applies the LT predicate on the "agent_version" field.
func AgentVersionLTE ¶
AgentVersionLTE applies the LTE predicate on the "agent_version" field.
func AgentVersionNEQ ¶
AgentVersionNEQ applies the NEQ predicate on the "agent_version" field.
func AgentVersionNotIn ¶
AgentVersionNotIn applies the NotIn predicate on the "agent_version" field.
func AgentVersionNotNil ¶
AgentVersionNotNil applies the NotNil predicate on the "agent_version" field.
func BlockedActions ¶ added in v0.5.0
BlockedActions applies equality check predicate on the "blocked_actions" field. It's identical to BlockedActionsEQ.
func BlockedActionsEQ ¶ added in v0.5.0
BlockedActionsEQ applies the EQ predicate on the "blocked_actions" field.
func BlockedActionsGT ¶ added in v0.5.0
BlockedActionsGT applies the GT predicate on the "blocked_actions" field.
func BlockedActionsGTE ¶ added in v0.5.0
BlockedActionsGTE applies the GTE predicate on the "blocked_actions" field.
func BlockedActionsIn ¶ added in v0.5.0
BlockedActionsIn applies the In predicate on the "blocked_actions" field.
func BlockedActionsLT ¶ added in v0.5.0
BlockedActionsLT applies the LT predicate on the "blocked_actions" field.
func BlockedActionsLTE ¶ added in v0.5.0
BlockedActionsLTE applies the LTE predicate on the "blocked_actions" field.
func BlockedActionsNEQ ¶ added in v0.5.0
BlockedActionsNEQ applies the NEQ predicate on the "blocked_actions" field.
func BlockedActionsNotIn ¶ added in v0.5.0
BlockedActionsNotIn applies the NotIn predicate on the "blocked_actions" field.
func CacheReadTokens ¶ added in v0.4.0
CacheReadTokens applies equality check predicate on the "cache_read_tokens" field. It's identical to CacheReadTokensEQ.
func CacheReadTokensEQ ¶ added in v0.4.0
CacheReadTokensEQ applies the EQ predicate on the "cache_read_tokens" field.
func CacheReadTokensGT ¶ added in v0.4.0
CacheReadTokensGT applies the GT predicate on the "cache_read_tokens" field.
func CacheReadTokensGTE ¶ added in v0.4.0
CacheReadTokensGTE applies the GTE predicate on the "cache_read_tokens" field.
func CacheReadTokensIn ¶ added in v0.4.0
CacheReadTokensIn applies the In predicate on the "cache_read_tokens" field.
func CacheReadTokensLT ¶ added in v0.4.0
CacheReadTokensLT applies the LT predicate on the "cache_read_tokens" field.
func CacheReadTokensLTE ¶ added in v0.4.0
CacheReadTokensLTE applies the LTE predicate on the "cache_read_tokens" field.
func CacheReadTokensNEQ ¶ added in v0.4.0
CacheReadTokensNEQ applies the NEQ predicate on the "cache_read_tokens" field.
func CacheReadTokensNotIn ¶ added in v0.4.0
CacheReadTokensNotIn applies the NotIn predicate on the "cache_read_tokens" field.
func CacheWriteTokens ¶ added in v0.4.0
CacheWriteTokens applies equality check predicate on the "cache_write_tokens" field. It's identical to CacheWriteTokensEQ.
func CacheWriteTokensEQ ¶ added in v0.4.0
CacheWriteTokensEQ applies the EQ predicate on the "cache_write_tokens" field.
func CacheWriteTokensGT ¶ added in v0.4.0
CacheWriteTokensGT applies the GT predicate on the "cache_write_tokens" field.
func CacheWriteTokensGTE ¶ added in v0.4.0
CacheWriteTokensGTE applies the GTE predicate on the "cache_write_tokens" field.
func CacheWriteTokensIn ¶ added in v0.4.0
CacheWriteTokensIn applies the In predicate on the "cache_write_tokens" field.
func CacheWriteTokensLT ¶ added in v0.4.0
CacheWriteTokensLT applies the LT predicate on the "cache_write_tokens" field.
func CacheWriteTokensLTE ¶ added in v0.4.0
CacheWriteTokensLTE applies the LTE predicate on the "cache_write_tokens" field.
func CacheWriteTokensNEQ ¶ added in v0.4.0
CacheWriteTokensNEQ applies the NEQ predicate on the "cache_write_tokens" field.
func CacheWriteTokensNotIn ¶ added in v0.4.0
CacheWriteTokensNotIn applies the NotIn predicate on the "cache_write_tokens" field.
func CommandsExecuted ¶
CommandsExecuted applies equality check predicate on the "commands_executed" field. It's identical to CommandsExecutedEQ.
func CommandsExecutedEQ ¶
CommandsExecutedEQ applies the EQ predicate on the "commands_executed" field.
func CommandsExecutedGT ¶
CommandsExecutedGT applies the GT predicate on the "commands_executed" field.
func CommandsExecutedGTE ¶
CommandsExecutedGTE applies the GTE predicate on the "commands_executed" field.
func CommandsExecutedIn ¶
CommandsExecutedIn applies the In predicate on the "commands_executed" field.
func CommandsExecutedLT ¶
CommandsExecutedLT applies the LT predicate on the "commands_executed" field.
func CommandsExecutedLTE ¶
CommandsExecutedLTE applies the LTE predicate on the "commands_executed" field.
func CommandsExecutedNEQ ¶
CommandsExecutedNEQ applies the NEQ predicate on the "commands_executed" field.
func CommandsExecutedNotIn ¶
CommandsExecutedNotIn applies the NotIn predicate on the "commands_executed" field.
func CostComputedAt ¶ added in v0.4.0
CostComputedAt applies equality check predicate on the "cost_computed_at" field. It's identical to CostComputedAtEQ.
func CostComputedAtEQ ¶ added in v0.4.0
CostComputedAtEQ applies the EQ predicate on the "cost_computed_at" field.
func CostComputedAtGT ¶ added in v0.4.0
CostComputedAtGT applies the GT predicate on the "cost_computed_at" field.
func CostComputedAtGTE ¶ added in v0.4.0
CostComputedAtGTE applies the GTE predicate on the "cost_computed_at" field.
func CostComputedAtIn ¶ added in v0.4.0
CostComputedAtIn applies the In predicate on the "cost_computed_at" field.
func CostComputedAtIsNil ¶ added in v0.4.0
CostComputedAtIsNil applies the IsNil predicate on the "cost_computed_at" field.
func CostComputedAtLT ¶ added in v0.4.0
CostComputedAtLT applies the LT predicate on the "cost_computed_at" field.
func CostComputedAtLTE ¶ added in v0.4.0
CostComputedAtLTE applies the LTE predicate on the "cost_computed_at" field.
func CostComputedAtNEQ ¶ added in v0.4.0
CostComputedAtNEQ applies the NEQ predicate on the "cost_computed_at" field.
func CostComputedAtNotIn ¶ added in v0.4.0
CostComputedAtNotIn applies the NotIn predicate on the "cost_computed_at" field.
func CostComputedAtNotNil ¶ added in v0.4.0
CostComputedAtNotNil applies the NotNil predicate on the "cost_computed_at" field.
func CostSource ¶ added in v0.4.0
CostSource applies equality check predicate on the "cost_source" field. It's identical to CostSourceEQ.
func CostSourceContains ¶ added in v0.4.0
CostSourceContains applies the Contains predicate on the "cost_source" field.
func CostSourceContainsFold ¶ added in v0.4.0
CostSourceContainsFold applies the ContainsFold predicate on the "cost_source" field.
func CostSourceEQ ¶ added in v0.4.0
CostSourceEQ applies the EQ predicate on the "cost_source" field.
func CostSourceEqualFold ¶ added in v0.4.0
CostSourceEqualFold applies the EqualFold predicate on the "cost_source" field.
func CostSourceGT ¶ added in v0.4.0
CostSourceGT applies the GT predicate on the "cost_source" field.
func CostSourceGTE ¶ added in v0.4.0
CostSourceGTE applies the GTE predicate on the "cost_source" field.
func CostSourceHasPrefix ¶ added in v0.4.0
CostSourceHasPrefix applies the HasPrefix predicate on the "cost_source" field.
func CostSourceHasSuffix ¶ added in v0.4.0
CostSourceHasSuffix applies the HasSuffix predicate on the "cost_source" field.
func CostSourceIn ¶ added in v0.4.0
CostSourceIn applies the In predicate on the "cost_source" field.
func CostSourceIsNil ¶ added in v0.4.0
CostSourceIsNil applies the IsNil predicate on the "cost_source" field.
func CostSourceLT ¶ added in v0.4.0
CostSourceLT applies the LT predicate on the "cost_source" field.
func CostSourceLTE ¶ added in v0.4.0
CostSourceLTE applies the LTE predicate on the "cost_source" field.
func CostSourceNEQ ¶ added in v0.4.0
CostSourceNEQ applies the NEQ predicate on the "cost_source" field.
func CostSourceNotIn ¶ added in v0.4.0
CostSourceNotIn applies the NotIn predicate on the "cost_source" field.
func CostSourceNotNil ¶ added in v0.4.0
CostSourceNotNil applies the NotNil predicate on the "cost_source" field.
func EndedAt ¶
EndedAt applies equality check predicate on the "ended_at" field. It's identical to EndedAtEQ.
func EndedAtGTE ¶
EndedAtGTE applies the GTE predicate on the "ended_at" field.
func EndedAtIsNil ¶
EndedAtIsNil applies the IsNil predicate on the "ended_at" field.
func EndedAtLTE ¶
EndedAtLTE applies the LTE predicate on the "ended_at" field.
func EndedAtNEQ ¶
EndedAtNEQ applies the NEQ predicate on the "ended_at" field.
func EndedAtNotIn ¶
EndedAtNotIn applies the NotIn predicate on the "ended_at" field.
func EndedAtNotNil ¶
EndedAtNotNil applies the NotNil predicate on the "ended_at" field.
func Errors ¶
Errors applies equality check predicate on the "errors" field. It's identical to ErrorsEQ.
func ErrorsNotIn ¶
ErrorsNotIn applies the NotIn predicate on the "errors" field.
func EstimatedCostUsd ¶ added in v0.4.0
EstimatedCostUsd applies equality check predicate on the "estimated_cost_usd" field. It's identical to EstimatedCostUsdEQ.
func EstimatedCostUsdEQ ¶ added in v0.4.0
EstimatedCostUsdEQ applies the EQ predicate on the "estimated_cost_usd" field.
func EstimatedCostUsdGT ¶ added in v0.4.0
EstimatedCostUsdGT applies the GT predicate on the "estimated_cost_usd" field.
func EstimatedCostUsdGTE ¶ added in v0.4.0
EstimatedCostUsdGTE applies the GTE predicate on the "estimated_cost_usd" field.
func EstimatedCostUsdIn ¶ added in v0.4.0
EstimatedCostUsdIn applies the In predicate on the "estimated_cost_usd" field.
func EstimatedCostUsdLT ¶ added in v0.4.0
EstimatedCostUsdLT applies the LT predicate on the "estimated_cost_usd" field.
func EstimatedCostUsdLTE ¶ added in v0.4.0
EstimatedCostUsdLTE applies the LTE predicate on the "estimated_cost_usd" field.
func EstimatedCostUsdNEQ ¶ added in v0.4.0
EstimatedCostUsdNEQ applies the NEQ predicate on the "estimated_cost_usd" field.
func EstimatedCostUsdNotIn ¶ added in v0.4.0
EstimatedCostUsdNotIn applies the NotIn predicate on the "estimated_cost_usd" field.
func FilesRead ¶
FilesRead applies equality check predicate on the "files_read" field. It's identical to FilesReadEQ.
func FilesReadEQ ¶
FilesReadEQ applies the EQ predicate on the "files_read" field.
func FilesReadGT ¶
FilesReadGT applies the GT predicate on the "files_read" field.
func FilesReadGTE ¶
FilesReadGTE applies the GTE predicate on the "files_read" field.
func FilesReadIn ¶
FilesReadIn applies the In predicate on the "files_read" field.
func FilesReadLT ¶
FilesReadLT applies the LT predicate on the "files_read" field.
func FilesReadLTE ¶
FilesReadLTE applies the LTE predicate on the "files_read" field.
func FilesReadNEQ ¶
FilesReadNEQ applies the NEQ predicate on the "files_read" field.
func FilesReadNotIn ¶
FilesReadNotIn applies the NotIn predicate on the "files_read" field.
func FilesWritten ¶
FilesWritten applies equality check predicate on the "files_written" field. It's identical to FilesWrittenEQ.
func FilesWrittenEQ ¶
FilesWrittenEQ applies the EQ predicate on the "files_written" field.
func FilesWrittenGT ¶
FilesWrittenGT applies the GT predicate on the "files_written" field.
func FilesWrittenGTE ¶
FilesWrittenGTE applies the GTE predicate on the "files_written" field.
func FilesWrittenIn ¶
FilesWrittenIn applies the In predicate on the "files_written" field.
func FilesWrittenLT ¶
FilesWrittenLT applies the LT predicate on the "files_written" field.
func FilesWrittenLTE ¶
FilesWrittenLTE applies the LTE predicate on the "files_written" field.
func FilesWrittenNEQ ¶
FilesWrittenNEQ applies the NEQ predicate on the "files_written" field.
func FilesWrittenNotIn ¶
FilesWrittenNotIn applies the NotIn predicate on the "files_written" field.
func HasEventsWith ¶
func HasEventsWith(preds ...predicate.AuditEvent) predicate.Session
HasEventsWith applies the HasEdge predicate on the "events" edge with a given conditions (other predicates).
func InputTokens ¶ added in v0.4.0
InputTokens applies equality check predicate on the "input_tokens" field. It's identical to InputTokensEQ.
func InputTokensEQ ¶ added in v0.4.0
InputTokensEQ applies the EQ predicate on the "input_tokens" field.
func InputTokensGT ¶ added in v0.4.0
InputTokensGT applies the GT predicate on the "input_tokens" field.
func InputTokensGTE ¶ added in v0.4.0
InputTokensGTE applies the GTE predicate on the "input_tokens" field.
func InputTokensIn ¶ added in v0.4.0
InputTokensIn applies the In predicate on the "input_tokens" field.
func InputTokensLT ¶ added in v0.4.0
InputTokensLT applies the LT predicate on the "input_tokens" field.
func InputTokensLTE ¶ added in v0.4.0
InputTokensLTE applies the LTE predicate on the "input_tokens" field.
func InputTokensNEQ ¶ added in v0.4.0
InputTokensNEQ applies the NEQ predicate on the "input_tokens" field.
func InputTokensNotIn ¶ added in v0.4.0
InputTokensNotIn applies the NotIn predicate on the "input_tokens" field.
func ModelUsageIsNil ¶ added in v0.4.0
ModelUsageIsNil applies the IsNil predicate on the "model_usage" field.
func ModelUsageNotNil ¶ added in v0.4.0
ModelUsageNotNil applies the NotNil predicate on the "model_usage" field.
func OutputTokens ¶ added in v0.4.0
OutputTokens applies equality check predicate on the "output_tokens" field. It's identical to OutputTokensEQ.
func OutputTokensEQ ¶ added in v0.4.0
OutputTokensEQ applies the EQ predicate on the "output_tokens" field.
func OutputTokensGT ¶ added in v0.4.0
OutputTokensGT applies the GT predicate on the "output_tokens" field.
func OutputTokensGTE ¶ added in v0.4.0
OutputTokensGTE applies the GTE predicate on the "output_tokens" field.
func OutputTokensIn ¶ added in v0.4.0
OutputTokensIn applies the In predicate on the "output_tokens" field.
func OutputTokensLT ¶ added in v0.4.0
OutputTokensLT applies the LT predicate on the "output_tokens" field.
func OutputTokensLTE ¶ added in v0.4.0
OutputTokensLTE applies the LTE predicate on the "output_tokens" field.
func OutputTokensNEQ ¶ added in v0.4.0
OutputTokensNEQ applies the NEQ predicate on the "output_tokens" field.
func OutputTokensNotIn ¶ added in v0.4.0
OutputTokensNotIn applies the NotIn predicate on the "output_tokens" field.
func ProjectName ¶
ProjectName applies equality check predicate on the "project_name" field. It's identical to ProjectNameEQ.
func ProjectNameContains ¶
ProjectNameContains applies the Contains predicate on the "project_name" field.
func ProjectNameContainsFold ¶
ProjectNameContainsFold applies the ContainsFold predicate on the "project_name" field.
func ProjectNameEQ ¶
ProjectNameEQ applies the EQ predicate on the "project_name" field.
func ProjectNameEqualFold ¶
ProjectNameEqualFold applies the EqualFold predicate on the "project_name" field.
func ProjectNameGT ¶
ProjectNameGT applies the GT predicate on the "project_name" field.
func ProjectNameGTE ¶
ProjectNameGTE applies the GTE predicate on the "project_name" field.
func ProjectNameHasPrefix ¶
ProjectNameHasPrefix applies the HasPrefix predicate on the "project_name" field.
func ProjectNameHasSuffix ¶
ProjectNameHasSuffix applies the HasSuffix predicate on the "project_name" field.
func ProjectNameIn ¶
ProjectNameIn applies the In predicate on the "project_name" field.
func ProjectNameIsNil ¶
ProjectNameIsNil applies the IsNil predicate on the "project_name" field.
func ProjectNameLT ¶
ProjectNameLT applies the LT predicate on the "project_name" field.
func ProjectNameLTE ¶
ProjectNameLTE applies the LTE predicate on the "project_name" field.
func ProjectNameNEQ ¶
ProjectNameNEQ applies the NEQ predicate on the "project_name" field.
func ProjectNameNotIn ¶
ProjectNameNotIn applies the NotIn predicate on the "project_name" field.
func ProjectNameNotNil ¶
ProjectNameNotNil applies the NotNil predicate on the "project_name" field.
func SensitiveActions ¶ added in v0.5.0
SensitiveActions applies equality check predicate on the "sensitive_actions" field. It's identical to SensitiveActionsEQ.
func SensitiveActionsEQ ¶ added in v0.5.0
SensitiveActionsEQ applies the EQ predicate on the "sensitive_actions" field.
func SensitiveActionsGT ¶ added in v0.5.0
SensitiveActionsGT applies the GT predicate on the "sensitive_actions" field.
func SensitiveActionsGTE ¶ added in v0.5.0
SensitiveActionsGTE applies the GTE predicate on the "sensitive_actions" field.
func SensitiveActionsIn ¶ added in v0.5.0
SensitiveActionsIn applies the In predicate on the "sensitive_actions" field.
func SensitiveActionsLT ¶ added in v0.5.0
SensitiveActionsLT applies the LT predicate on the "sensitive_actions" field.
func SensitiveActionsLTE ¶ added in v0.5.0
SensitiveActionsLTE applies the LTE predicate on the "sensitive_actions" field.
func SensitiveActionsNEQ ¶ added in v0.5.0
SensitiveActionsNEQ applies the NEQ predicate on the "sensitive_actions" field.
func SensitiveActionsNotIn ¶ added in v0.5.0
SensitiveActionsNotIn applies the NotIn predicate on the "sensitive_actions" field.
func StartedAt ¶
StartedAt applies equality check predicate on the "started_at" field. It's identical to StartedAtEQ.
func StartedAtEQ ¶
StartedAtEQ applies the EQ predicate on the "started_at" field.
func StartedAtGT ¶
StartedAtGT applies the GT predicate on the "started_at" field.
func StartedAtGTE ¶
StartedAtGTE applies the GTE predicate on the "started_at" field.
func StartedAtIn ¶
StartedAtIn applies the In predicate on the "started_at" field.
func StartedAtLT ¶
StartedAtLT applies the LT predicate on the "started_at" field.
func StartedAtLTE ¶
StartedAtLTE applies the LTE predicate on the "started_at" field.
func StartedAtNEQ ¶
StartedAtNEQ applies the NEQ predicate on the "started_at" field.
func StartedAtNotIn ¶
StartedAtNotIn applies the NotIn predicate on the "started_at" field.
func TotalActions ¶
TotalActions applies equality check predicate on the "total_actions" field. It's identical to TotalActionsEQ.
func TotalActionsEQ ¶
TotalActionsEQ applies the EQ predicate on the "total_actions" field.
func TotalActionsGT ¶
TotalActionsGT applies the GT predicate on the "total_actions" field.
func TotalActionsGTE ¶
TotalActionsGTE applies the GTE predicate on the "total_actions" field.
func TotalActionsIn ¶
TotalActionsIn applies the In predicate on the "total_actions" field.
func TotalActionsLT ¶
TotalActionsLT applies the LT predicate on the "total_actions" field.
func TotalActionsLTE ¶
TotalActionsLTE applies the LTE predicate on the "total_actions" field.
func TotalActionsNEQ ¶
TotalActionsNEQ applies the NEQ predicate on the "total_actions" field.
func TotalActionsNotIn ¶
TotalActionsNotIn applies the NotIn predicate on the "total_actions" field.
func TranscriptPath ¶ added in v0.4.0
TranscriptPath applies equality check predicate on the "transcript_path" field. It's identical to TranscriptPathEQ.
func TranscriptPathContains ¶ added in v0.4.0
TranscriptPathContains applies the Contains predicate on the "transcript_path" field.
func TranscriptPathContainsFold ¶ added in v0.4.0
TranscriptPathContainsFold applies the ContainsFold predicate on the "transcript_path" field.
func TranscriptPathEQ ¶ added in v0.4.0
TranscriptPathEQ applies the EQ predicate on the "transcript_path" field.
func TranscriptPathEqualFold ¶ added in v0.4.0
TranscriptPathEqualFold applies the EqualFold predicate on the "transcript_path" field.
func TranscriptPathGT ¶ added in v0.4.0
TranscriptPathGT applies the GT predicate on the "transcript_path" field.
func TranscriptPathGTE ¶ added in v0.4.0
TranscriptPathGTE applies the GTE predicate on the "transcript_path" field.
func TranscriptPathHasPrefix ¶ added in v0.4.0
TranscriptPathHasPrefix applies the HasPrefix predicate on the "transcript_path" field.
func TranscriptPathHasSuffix ¶ added in v0.4.0
TranscriptPathHasSuffix applies the HasSuffix predicate on the "transcript_path" field.
func TranscriptPathIn ¶ added in v0.4.0
TranscriptPathIn applies the In predicate on the "transcript_path" field.
func TranscriptPathIsNil ¶ added in v0.4.0
TranscriptPathIsNil applies the IsNil predicate on the "transcript_path" field.
func TranscriptPathLT ¶ added in v0.4.0
TranscriptPathLT applies the LT predicate on the "transcript_path" field.
func TranscriptPathLTE ¶ added in v0.4.0
TranscriptPathLTE applies the LTE predicate on the "transcript_path" field.
func TranscriptPathNEQ ¶ added in v0.4.0
TranscriptPathNEQ applies the NEQ predicate on the "transcript_path" field.
func TranscriptPathNotIn ¶ added in v0.4.0
TranscriptPathNotIn applies the NotIn predicate on the "transcript_path" field.
func TranscriptPathNotNil ¶ added in v0.4.0
TranscriptPathNotNil applies the NotNil predicate on the "transcript_path" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func WorkingDirectory ¶
WorkingDirectory applies equality check predicate on the "working_directory" field. It's identical to WorkingDirectoryEQ.
func WorkingDirectoryContains ¶
WorkingDirectoryContains applies the Contains predicate on the "working_directory" field.
func WorkingDirectoryContainsFold ¶
WorkingDirectoryContainsFold applies the ContainsFold predicate on the "working_directory" field.
func WorkingDirectoryEQ ¶
WorkingDirectoryEQ applies the EQ predicate on the "working_directory" field.
func WorkingDirectoryEqualFold ¶
WorkingDirectoryEqualFold applies the EqualFold predicate on the "working_directory" field.
func WorkingDirectoryGT ¶
WorkingDirectoryGT applies the GT predicate on the "working_directory" field.
func WorkingDirectoryGTE ¶
WorkingDirectoryGTE applies the GTE predicate on the "working_directory" field.
func WorkingDirectoryHasPrefix ¶
WorkingDirectoryHasPrefix applies the HasPrefix predicate on the "working_directory" field.
func WorkingDirectoryHasSuffix ¶
WorkingDirectoryHasSuffix applies the HasSuffix predicate on the "working_directory" field.
func WorkingDirectoryIn ¶
WorkingDirectoryIn applies the In predicate on the "working_directory" field.
func WorkingDirectoryIsNil ¶
WorkingDirectoryIsNil applies the IsNil predicate on the "working_directory" field.
func WorkingDirectoryLT ¶
WorkingDirectoryLT applies the LT predicate on the "working_directory" field.
func WorkingDirectoryLTE ¶
WorkingDirectoryLTE applies the LTE predicate on the "working_directory" field.
func WorkingDirectoryNEQ ¶
WorkingDirectoryNEQ applies the NEQ predicate on the "working_directory" field.
func WorkingDirectoryNotIn ¶
WorkingDirectoryNotIn applies the NotIn predicate on the "working_directory" field.
func WorkingDirectoryNotNil ¶
WorkingDirectoryNotNil applies the NotNil predicate on the "working_directory" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Session queries.
func ByAgentName ¶
func ByAgentName(opts ...sql.OrderTermOption) OrderOption
ByAgentName orders the results by the agent_name field.
func ByAgentSessionID ¶
func ByAgentSessionID(opts ...sql.OrderTermOption) OrderOption
ByAgentSessionID orders the results by the agent_session_id field.
func ByAgentVersion ¶
func ByAgentVersion(opts ...sql.OrderTermOption) OrderOption
ByAgentVersion orders the results by the agent_version field.
func ByBlockedActions ¶ added in v0.5.0
func ByBlockedActions(opts ...sql.OrderTermOption) OrderOption
ByBlockedActions orders the results by the blocked_actions field.
func ByCacheReadTokens ¶ added in v0.4.0
func ByCacheReadTokens(opts ...sql.OrderTermOption) OrderOption
ByCacheReadTokens orders the results by the cache_read_tokens field.
func ByCacheWriteTokens ¶ added in v0.4.0
func ByCacheWriteTokens(opts ...sql.OrderTermOption) OrderOption
ByCacheWriteTokens orders the results by the cache_write_tokens field.
func ByCommandsExecuted ¶
func ByCommandsExecuted(opts ...sql.OrderTermOption) OrderOption
ByCommandsExecuted orders the results by the commands_executed field.
func ByCostComputedAt ¶ added in v0.4.0
func ByCostComputedAt(opts ...sql.OrderTermOption) OrderOption
ByCostComputedAt orders the results by the cost_computed_at field.
func ByCostSource ¶ added in v0.4.0
func ByCostSource(opts ...sql.OrderTermOption) OrderOption
ByCostSource orders the results by the cost_source field.
func ByEndedAt ¶
func ByEndedAt(opts ...sql.OrderTermOption) OrderOption
ByEndedAt orders the results by the ended_at field.
func ByErrors ¶
func ByErrors(opts ...sql.OrderTermOption) OrderOption
ByErrors orders the results by the errors field.
func ByEstimatedCostUsd ¶ added in v0.4.0
func ByEstimatedCostUsd(opts ...sql.OrderTermOption) OrderOption
ByEstimatedCostUsd orders the results by the estimated_cost_usd field.
func ByEvents ¶
func ByEvents(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEvents orders the results by events terms.
func ByEventsCount ¶
func ByEventsCount(opts ...sql.OrderTermOption) OrderOption
ByEventsCount orders the results by events count.
func ByFilesRead ¶
func ByFilesRead(opts ...sql.OrderTermOption) OrderOption
ByFilesRead orders the results by the files_read field.
func ByFilesWritten ¶
func ByFilesWritten(opts ...sql.OrderTermOption) OrderOption
ByFilesWritten orders the results by the files_written field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByInputTokens ¶ added in v0.4.0
func ByInputTokens(opts ...sql.OrderTermOption) OrderOption
ByInputTokens orders the results by the input_tokens field.
func ByOutputTokens ¶ added in v0.4.0
func ByOutputTokens(opts ...sql.OrderTermOption) OrderOption
ByOutputTokens orders the results by the output_tokens field.
func ByProjectName ¶
func ByProjectName(opts ...sql.OrderTermOption) OrderOption
ByProjectName orders the results by the project_name field.
func BySensitiveActions ¶ added in v0.5.0
func BySensitiveActions(opts ...sql.OrderTermOption) OrderOption
BySensitiveActions orders the results by the sensitive_actions field.
func ByStartedAt ¶
func ByStartedAt(opts ...sql.OrderTermOption) OrderOption
ByStartedAt orders the results by the started_at field.
func ByTotalActions ¶
func ByTotalActions(opts ...sql.OrderTermOption) OrderOption
ByTotalActions orders the results by the total_actions field.
func ByTranscriptPath ¶ added in v0.4.0
func ByTranscriptPath(opts ...sql.OrderTermOption) OrderOption
ByTranscriptPath orders the results by the transcript_path field.
func ByWorkingDirectory ¶
func ByWorkingDirectory(opts ...sql.OrderTermOption) OrderOption
ByWorkingDirectory orders the results by the working_directory field.